@@ -42,7 +42,7 @@ if ($canDo->get('core.edit'))
 JToolBarHelper::cancel();
 
 jimport('joomla.html.editor');
-$editor = JEditor::getInstance();
+$editor =& JEditor::getInstance();
 
 //set the escape callback
 $this->setEscape("htmlentities");
@@ -66,9 +66,10 @@ $short_title = (!preg_match('!\S!u', $short_title)) ? utf8_encode($short_title)
 $journal = html_entity_decode($this->row->journal);
 $journal = (!preg_match('!\S!u', $journal)) ? utf8_encode($journal) : $journal;
 ?>
-
-<script type="text/javascript" src="/components/com_citations/assets/js/citations.jquery.js"></script>
-
+<!--
+<script type="text/javascript" src="../includes/js/mootools.js"></script>
+<script type="text/javascript" src="components/com_citations/citations.js"></script>
+-->
 <script type="text/javascript">
 function submitbutton(pressbutton) 
 {
@@ -287,7 +288,7 @@ function submitbutton(pressbutton)
 				</thead>
 				<tfoot>
 					<tr>
-						<td colspan="3"><a href="#" onclick="HUB.Citations.addRow('assocs');return false;"><?php echo JText::_('ADD_A_ROW'); ?></a></td>
+						<td colspan="3"><a href="#" onclick="Citations.addRow('assocs');return false;"><?php echo JText::_('ADD_A_ROW'); ?></a></td>
 					</tr>
 				</tfoot>
 				<tbody>
