@@ -47,7 +47,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 	public function displayTask()
 	{
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
@@ -324,7 +324,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 		foreach ($mbrs as $mbr)
 		{
 			// Retrieve user's account info
-			$targetuser = JUser::getInstance($mbr);
+			$targetuser =& JUser::getInstance($mbr);
 
 			// Ensure we found an account
 			if (is_object($targetuser))
@@ -397,7 +397,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 		foreach ($mbrs as $mbr)
 		{
 			// Retrieve user's account info
-			$targetuser = JUser::getInstance($mbr);
+			$targetuser =& JUser::getInstance($mbr);
 
 			// Ensure we found an account
 			if (is_object($targetuser))
@@ -469,7 +469,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 		foreach ($mbrs as $mbr)
 		{
 			// Retrieve user's account info
-			$targetuser = JUser::getInstance($mbr);
+			$targetuser =& JUser::getInstance($mbr);
 
 			// Ensure we found an account
 			if (is_object($targetuser))
@@ -549,7 +549,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 		foreach ($mbrs as $mbr)
 		{
 			// Retrieve user's account info
-			$targetuser = JUser::getInstance($mbr);
+			$targetuser =& JUser::getInstance($mbr);
 
 			// Ensure we found an account
 			if (is_object($targetuser))
@@ -620,7 +620,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 		foreach ($mbrs as $mbr)
 		{
 			// Retrieve user's account info
-			$targetuser = JUser::getInstance($mbr);
+			$targetuser =& JUser::getInstance($mbr);
 
 			// Ensure we found an account
 			if (is_object($targetuser))
@@ -704,7 +704,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 			else
 			{
 				// Retrieve user's account info
-				$targetuser = JUser::getInstance($mbr);
+				$targetuser =& JUser::getInstance($mbr);
 				
 				// Ensure we found an account
 				if (is_object($targetuser))
@@ -770,7 +770,7 @@ class GroupsControllerMembership extends Hubzero_Controller
 		foreach ($mbrs as $mbr)
 		{
 			// Retrieve user's account info
-			$targetuser = JUser::getInstance($mbr);
+			$targetuser =& JUser::getInstance($mbr);
 
 			// Ensure we found an account
 			if (is_object($targetuser))
