@@ -179,8 +179,8 @@ class Publication extends JTable
 	 */	
 	public function buildQuery( $filters = array(), $usergroups = array() ) 
 	{
-		$juser = JFactory::getUser();
-		$now = JFactory::getDate()->toSql();
+		$juser =& JFactory::getUser();
+		$now = date( 'Y-m-d H:i:s', time() );
 		$restricted = 0;
 		$groupby = ' GROUP BY C.id ';
 		
@@ -507,8 +507,8 @@ class Publication extends JTable
 			return false;
 		}
 		
-		$juser = JFactory::getUser();
-		$now = JFactory::getDate()->toSql();
+		$juser =& JFactory::getUser();
+		$now = date( 'Y-m-d H:i:s', time() );
 		$alias = str_replace( ':', '-', $alias );
 		
 		$sql  = "SELECT V.*, C.id as id, C.category, C.master_type, C.project_id, C.access as master_access, 
@@ -598,7 +598,7 @@ class Publication extends JTable
 	}
 	
 	/**
-	 * Delete publication existence
+	 * Delete publication existance
 	 * 
 	 * @param      integer 		$id
 	 * @return     void
@@ -611,7 +611,6 @@ class Publication extends JTable
 		}
 		
 		// Delete child associations
-		/*
 		$this->_db->setQuery( "DELETE FROM #__publication_assoc WHERE child_version_id=".$id );
 		if (!$this->_db->query()) 
 		{
@@ -625,8 +624,6 @@ class Publication extends JTable
 			echo $this->_db->getErrorMsg();
 			exit;
 		}
-		*/
-		
 		// Delete tag associations
 		$this->_db->setQuery( "DELETE FROM #__tags_object WHERE tbl='publications' AND objectid=".$id );
 		if (!$this->_db->query()) 
@@ -650,7 +647,7 @@ class Publication extends JTable
 	 * @param      string 	$get
 	 * @return     mixed
 	 */	
-	public function getPubStats ( $validProjects = array(), $get = 'total', $when = NULL) 
+	public function getPubStats ( $validProjects = array(), $get = 'total') 
 	{	
 		if (empty($validProjects))
 		{
@@ -707,11 +704,6 @@ class Publication extends JTable
 		if ($get == 'advanced' || $get == 'released')
 		{
 			$query .= $get == 'advanced' ? " AND (V.state = 4 OR V.state = 6 OR V.state = 5)  " : " AND V.state = 1 AND V.main = 1";
-			
-			if ($when)
-			{
-				$query .= " AND V.published_up LIKE '" . $when . "%' ";
-			}
 		}
 				
 		if ($get == 'average')
