@@ -249,7 +249,7 @@ class ResourcesResource extends JTable
 	 * @param      string $oid Resource alias
 	 * @return     boolean True on success
 	 */
-	public function load($oid=NULL, $reset = true)
+	public function load($oid=NULL)
 	{
 		if ($oid === NULL) 
 		{
@@ -257,7 +257,7 @@ class ResourcesResource extends JTable
 		}
 		if (is_numeric($oid))
 		{
-			return parent::load($oid, $reset);
+			return parent::load($oid);
 		}
 		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE `alias`=" . $this->_db->Quote($oid));
 		if ($result = $this->_db->loadAssoc()) 
@@ -462,8 +462,8 @@ class ResourcesResource extends JTable
 	 */
 	public function buildQuery($filters=array())
 	{
-		$juser = JFactory::getUser();
-		$now = JFactory::getDate()->toSql();
+		$juser =& JFactory::getUser();
+		$now = date('Y-m-d H:i:s', time());
 
 		$query  = "";
 		if (isset($filters['tag']) && $filters['tag'] != '') 
@@ -525,8 +525,7 @@ class ResourcesResource extends JTable
 			$xgroups = (is_object($profile)) ? $profile->getGroups('all') : array();
 			if ($xgroups != '') 
 			{
-				$usersgroups = self::getUsersGroups($xgroups);
-
+				$usersgroups = $this->getUsersGroups($xgroups);
 				if (count($usersgroups) > 1) 
 				{
 					$groups = implode("','", $usersgroups);
@@ -605,10 +604,9 @@ class ResourcesResource extends JTable
 	 * @param      array $groups User's groups
 	 * @return     array
 	 */
-	public static function getUsersGroups($groups)
+	public function getUsersGroups($groups)
 	{
 		$arr = array();
-
 		if (!empty($groups)) 
 		{
 			foreach ($groups as $group)
@@ -619,7 +617,6 @@ class ResourcesResource extends JTable
 				}
 			}
 		}
-
 		return $arr;
 	}
 
@@ -668,8 +665,8 @@ class ResourcesResource extends JTable
 	 */
 	public function buildPluginQuery($filters=array())
 	{
-		$database = JFactory::getDBO();
-		$juser = JFactory::getUser();
+		$database =& JFactory::getDBO();
+		$juser =& JFactory::getUser();
 
 		include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'type.php');
 		$rt = new ResourcesType($database);
@@ -776,11 +773,11 @@ class ResourcesResource extends JTable
 			$query .= ", #__tags_object AS t ";
 		}
 		$query .= "WHERE r.standalone=1 ";
-		if ($juser->get('guest') || !isset($filters['authorized']) || (isset($filters['authorized']) && !$filters['authorized'])) 
+		if ($juser->get('guest') || (isset($filters['authorized']) && !$filters['authorized'])) 
 		{
 			$query .= "AND r.published=1 ";
 		}
-		else if (isset($filters['authorized']) && $filters['authorized'])
+		else
 		{
 			$query .= "AND r.published!=4 ";
 		}
@@ -851,7 +848,7 @@ class ResourcesResource extends JTable
 				} 
 				else if ($xgroups != '') 
 				{
-					$usersgroups = self::getUsersGroups($xgroups);
+					$usersgroups = $this->getUsersGroups($xgroups);
 					if (count($usersgroups) > 1) 
 					{
 						$groups = implode("','", $usersgroups);
