@@ -31,14 +31,12 @@
 defined('_JEXEC') or die( 'Restricted access' );
 
 $text = ( $this->task == 'edit' ? JText::_( 'Edit' ) : JText::_( 'New' ) );
-JToolBarHelper::title( JText::_( 'Ticket' ).': '. $text, 'support.png' );
+JToolBarHelper::title( JText::_( 'Ticket' ).': <small><small>[ '. $text.' ]</small></small>', 'support.png' );
 JToolBarHelper::save();
 JToolBarHelper::apply();
 JToolBarHelper::cancel();
-JToolBarHelper::spacer();
-JToolBarHelper::help('ticket.html', true);
 
-$juser = JFactory::getUser();
+$juser =& JFactory::getUser();
 
 ximport('Hubzero_User');
 $user = new Hubzero_User_Profile();
@@ -46,7 +44,6 @@ $user = new Hubzero_User_Profile();
 $user->load($juser->get('id'));
 $unknown = true;
 $name = '';
-$usertype = JText::_('Unknown');
 $notify = array();
 
 $submitter = new Hubzero_User_Profile();
@@ -56,16 +53,6 @@ if ($this->row->login)
 	$submitter->load($this->row->login);
 	if (is_object($submitter) && $submitter->get('name')) 
 	{
-		if (version_compare(JVERSION, '1.6', 'lt'))
-		{
-			$usertype = JUser::getInstance($submitter->get('uidNumber'))->get('usertype');
-		} 
-		else
-		{
-			jimport( 'joomla.user.helper' );
-			$usertype = implode(', ', JUserHelper::getUserGroups($submitter->get('uidNumber')));
-		}
-
 		$this->row->name = ($this->row->name) ? $this->row->name : stripslashes($submitter->get('name'));
 		$name = '<a rel="profile" href="' . JRoute::_('index.php?option=com_members&amp;task=edit&amp;id[]=' . $submitter->get('uidNumber')) . '">' . $this->escape($this->row->name) . ' (' . $this->escape(stripslashes($submitter->get('username'))) . ')</a>';
 		$unknown = false;
@@ -99,12 +86,25 @@ if ($this->row->owner)
 }
 
 //jimport('joomla.html.editor');
-//$editor = JEditor::getInstance();
+//$editor =& JEditor::getInstance();
 
 ximport('Hubzero_User_Profile');
 
+if (version_compare(JVERSION, '1.6', 'lt'))
+{
+	$dateFormat = '%d %b, %Y';
+	$timeFormat = '%I:%M %p';
+	$tz = 0;
+}
+else 
+{
+	$dateFormat = 'd M, Y';
+	$timeFormat = 'H:m a';
+	$tz = true;
+}
+
 JPluginHelper::importPlugin( 'hubzero' );
-$dispatcher = JDispatcher::getInstance();
+$dispatcher =& JDispatcher::getInstance();
 
 $cc = array();
 ?>
@@ -140,7 +140,7 @@ if ($this->row->id) {
 		
 		if (count($this->comments) > 0) { 
 			$last = end($this->comments);
-			$lastactivity = '<time>' . JHTML::_('date', $last->created, JText::_('TIME_FORMAT_HZ1')) . '</time>';
+			$lastactivity = '<time>' . JHTML::_('date', $last->created, $timeFormat, $tz) . '</time>';
 		} else {
 			$lastactivity = JText::_('N/A');
 		}
@@ -159,8 +159,8 @@ if ($this->row->id) {
 						<?php echo $name; ?>
 					</strong>
 					<a class="permalink" href="index.php?option=com_support&amp;controller=tickets&amp;task=edit&amp;id=<?php echo $this->row->id; ?>" title="<?php echo JText::_('Permalink'); ?>">@ 
-						<span class="time"><time><?php echo JHTML::_('date', $this->row->created, JText::_('TIME_FORMAT_HZ1')); ?></time></span> <?php echo JText::_('on'); ?> 
-						<span class="date"><time><?php echo JHTML::_('date', $this->row->created, JText::_('DATE_FORMAT_HZ1')); ?></time></span>
+						<span class="time"><time><?php echo JHTML::_('date', $this->row->created, $timeFormat, $tz); ?></time></span> <?php echo JText::_('on'); ?> 
+						<span class="date"><time><?php echo JHTML::_('date', $this->row->created, $dateFormat, $tz); ?></time></span>
 					</a>
 				</div>
 				<blockquote class="ticket-content" cite="<?php echo ($this->row->login) ? $this->escape($this->row->login) : $this->escape($this->row->name); ?>">
@@ -173,10 +173,6 @@ if ($this->row->id) {
 								<th scope="row"><?php echo JText::_('TICKET_DETAILS_EMAIL'); ?>:</th>
 								<td><a href="mailto:<?php echo $this->row->email; ?>"><?php echo $this->escape($this->row->email); ?></a></td>
 							</tr>
-							<tr>
-								<th scope="row"><?php echo JText::_('TICKET_DETAILS_USERTYPE'); ?>:</th>
-								<td><?php echo $this->escape($usertype); ?></td>
-							</tr>
 							<tr>
 								<th scope="row"><?php echo JText::_('TICKET_DETAILS_OS'); ?>:</th>
 								<td><?php echo $this->escape($this->row->os); ?> / <?php echo $this->escape($this->row->browser); ?> (<?php echo ($this->row->cookies) ? JText::_('COOKIES_ENABLED') : JText::_('COOKIES_DISABLED'); ?>)</td>
@@ -293,7 +289,7 @@ if ($this->row->id) {
 				$anon = 1;
 				if ($comment->created_by) 
 				{
-					//$juseri = JUser::getInstance($comment->created_by);
+					//$juseri =& JUser::getInstance($comment->created_by);
 					if (is_object($useri)) 
 					{
 						$name = '<a rel="profile" href="index.php?option=com_members&amp;task=edit&amp;id[]=' . $useri->get('uidNumber') . '">' . $this->escape(stripslashes($useri->get('name'))) . ' (' . $this->escape(stripslashes($useri->get('username'))) . ')</a>';
@@ -312,8 +308,8 @@ if ($this->row->id) {
 							<?php echo $name; ?>
 						</strong>
 						<a class="permalink" href="<?php echo 'index.php?option=com_support&controller=tickets&task=edit&amp;id=' . $this->row->id . '#c' . $comment->id; ?>" title="<?php echo JText::_('permalink'); ?>">@ 
-							<span class="time"><time><?php echo JHTML::_('date',$comment->created, JText::_('TIME_FORMAT_HZ1')); ?></time></span> <?php echo JText::_('on'); ?>
-							<span class="date"><time><?php echo JHTML::_('date',$comment->created, JText::_('DATE_FORMAT_HZ1')); ?></time></span>
+							<span class="time"><time><?php echo JHTML::_('date',$comment->created, $dateFormat, $tz); ?></time></span> <?php echo JText::_('on'); ?>
+							<span class="date"><time><?php echo JHTML::_('date',$comment->created, $timeFormat, $tz); ?></time></span>
 						</a>
 					</p>
 <?php if ($comment->comment) { ?>
@@ -497,12 +493,6 @@ if ($this->row->id) {
 							</select>
 						</td>
 					</tr>
-					<tr>
-						<td class="key"><label for="comment-field-message"><?php echo JText::_('COMMENT_SEND_EMAIL_CC'); ?></label></td>
-						<td colspan="3">
-							<input type="text" name="cc" id="comment-field-message" value="" />
-						</td>
-					</tr>
 				</tbody>
 			</table>
 			<input type="hidden" name="section" value="1" />
@@ -525,8 +515,8 @@ if ($this->row->id) {
 						</a>
 					</strong>
 					<span class="permalink">
-						<?php echo JText::_('@'); ?> <span class="time"><time><?php echo JHTML::_('date', JFactory::getDate()->toSql(), JText::_('TIME_FORMAT_HZ1')); ?></time></span> 
-						<?php echo JText::_('on'); ?> <span class="date"><time><?php echo JHTML::_('date', JFactory::getDate()->toSql(), JText::_('DATE_FORMAT_HZ1')); ?></time></span>
+						<?php echo JText::_('@'); ?> <span class="time"><time><?php echo JHTML::_('date', date("Y-m-d H:i:s"), $dateFormat, $tz); ?></time></span> 
+						<?php echo JText::_('on'); ?> <span class="date"><time><?php echo JHTML::_('date', date("Y-m-d H:i:s"), $timeFormat, $tz); ?></time></span>
 					</span>
 
 					<label for="comment-field-access" class="private">
