@@ -31,21 +31,41 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'tables' . DS . 'entry.php');
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'models' . DS . 'tags.php');
+if (version_compare(JVERSION, '1.6', 'ge'))
+{
+	define('BLOG_DATE_YEAR', "Y");
+	define('BLOG_DATE_MONTH', "m");
+	define('BLOG_DATE_DAY', "d");
+	define('BLOG_DATE_TIMEZONE', true);
+	define('BLOG_DATE_FORMAT', 'd M Y');
+	define('BLOG_TIME_FORMAT', 'H:i p');
+}
+else
+{
+	define('BLOG_DATE_YEAR', "%Y");
+	define('BLOG_DATE_MONTH', "%m");
+	define('BLOG_DATE_DAY', "%d");
+	define('BLOG_DATE_TIMEZONE', 0);
+	define('BLOG_DATE_FORMAT', '%d %b %Y');
+	define('BLOG_TIME_FORMAT', '%I:%M %p');
+}
+
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'tables' . DS . 'blog.entry.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'helpers' . DS . 'blog.tags.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'models' . DS . 'comment.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'models' . DS . 'iterator.php');
 
 /**
  * Courses model class for a forum
  */
-class BlogModelEntry extends \Hubzero\Model
+class BlogModelEntry extends JObject
 {
 	/**
-	 * Table name
+	 * ForumTableSection
 	 * 
-	 * @var string
+	 * @var object
 	 */
-	protected $_tbl_name = 'BlogTableEntry';
+	private $_tbl = null;
 
 	/**
 	 * BlogModelComment
@@ -55,7 +75,7 @@ class BlogModelEntry extends \Hubzero\Model
 	private $_comment = null;
 
 	/**
-	 * \Hubzero\ItemList
+	 * BlogModelIterator
 	 * 
 	 * @var object
 	 */
@@ -68,6 +88,13 @@ class BlogModelEntry extends \Hubzero\Model
 	 */
 	private $_comments_count = null;
 
+	/**
+	 * Flag for if authorization checks have been run
+	 * 
+	 * @var mixed
+	 */
+	private $_authorized = false;
+
 	/**
 	 * JUser
 	 * 
@@ -76,32 +103,23 @@ class BlogModelEntry extends \Hubzero\Model
 	private $_creator = NULL;
 
 	/**
-	 * JRegistry
+	 * JDatabase
 	 * 
 	 * @var object
 	 */
-	public $params = NULL;
-
-	/**
-	 * Scope adapter
-	 * 
-	 * @var object
-	 */
-	private $_adapter = null;
+	private $_db = NULL;
 
 	/**
 	 * Constructor
 	 * 
-	 * @param      mixed   $oid      ID (int) or alias (string)
-	 * @param      string  $scope    site|member|group
-	 * @param      integer $group_id Group ID if scope is 'group'
+	 * @param      integer $id Course ID or alias
 	 * @return     void
 	 */
 	public function __construct($oid, $scope=null, $group_id=null)
 	{
 		$this->_db = JFactory::getDBO();
 
-		$this->_tbl = new BlogTableEntry($this->_db);
+		$this->_tbl = new BlogEntry($this->_db);
 
 		if (is_numeric($oid))
 		{
@@ -118,9 +136,29 @@ class BlogModelEntry extends \Hubzero\Model
 				$this->_tbl->loadAlias($oid, $scope, null, $group_id);
 			}
 		}
-		else if (is_object($oid) || is_array($oid))
+		else if (is_object($oid))
 		{
-			$this->bind($oid);
+			$this->_tbl->bind($oid);
+			$properties = $this->_tbl->getProperties();
+			foreach (get_object_vars($oid) as $key => $property)
+			{
+				if (!array_key_exists($key, $properties)) // && in_array($property, self::$_section_keys))
+				{
+					$this->_tbl->set('__' . $key, $property);
+				}
+			}
+		}
+		else if (is_array($oid))
+		{
+			$this->_tbl->bind($oid);
+			$properties = $this->_tbl->getProperties();
+			foreach (array_keys($oid) as $key)
+			{
+				if (!array_key_exists($key, $properties)) // && in_array($property, self::$_section_keys))
+				{
+					$this->_tbl->set('__' . $key, $oid[$key]);
+				}
+			}
 		}
 
 		$paramsClass = 'JParameter';
@@ -132,15 +170,13 @@ class BlogModelEntry extends \Hubzero\Model
 	}
 
 	/**
-	 * Returns a reference to a blog entry model
+	 * Returns a reference to a forum model
 	 *
 	 * This method must be invoked as:
-	 *     $offering = BlogModelentry::getInstance($alias, $scope, $group_id);
+	 *     $offering = ForumModelCourse::getInstance($alias);
 	 *
-	 * @param      mixed   $oid      ID (int) or alias (string)
-	 * @param      string  $scope    site|member|group
-	 * @param      integer $group_id Group ID if scope is 'group'
-	 * @return     object BlogModelentry
+	 * @param      mixed $oid Course ID (int) or alias (string)
+	 * @return     object ForumModelCourse
 	 */
 	static function &getInstance($oid=null, $scope=null, $group_id=null)
 	{
@@ -160,22 +196,129 @@ class BlogModelEntry extends \Hubzero\Model
 	}
 
 	/**
-	 * Has the publish window started?
+	 * Returns a property of the object or the default value if the property is not set.
+	 *
+	 * @param	string $property The name of the property
+	 * @param	mixed  $default The default value
+	 * @return	mixed The value of the property
+ 	 */
+	public function get($property, $default=null)
+	{
+		if (isset($this->_tbl->$property)) 
+		{
+			return $this->_tbl->$property;
+		}
+		else if (isset($this->_tbl->{'__' . $property})) 
+		{
+			return $this->_tbl->{'__' . $property};
+		}
+		return $default;
+	}
+
+	/**
+	 * Modifies a property of the object, creating it if it does not already exist.
+	 *
+	 * @param	string $property The name of the property
+	 * @param	mixed  $value The value of the property to set
+	 * @return	mixed Previous value of the property
+	 */
+	public function set($property, $value = null)
+	{
+		if (!array_key_exists($property, $this->_tbl->getProperties()))
+		{
+			$property = '__' . $property;
+		}
+		$previous = isset($this->_tbl->$property) ? $this->_tbl->$property : null;
+		$this->_tbl->$property = $value;
+		return $previous;
+	}
+
+	/**
+	 * Check if the forum exists
+	 * 
+	 * @param      mixed $idx Index value
+	 * @return     array
+	 */
+	public function exists()
+	{
+		if ($this->get('id') && (int) $this->get('id') > 0) 
+		{
+			return true;
+		}
+		return false;
+	}
+
+	/**
+	 * Has the offering started?
+	 * 
+	 * @return     boolean
+	 */
+	public function isPublished()
+	{
+		if (!in_array('state', array_keys($this->_tbl->getProperties())))
+		{
+			return true;
+		}
+		if ($this->get('state') == 1) 
+		{
+			return true;
+		}
+		return false;
+	}
+
+	/**
+	 * Has the offering started?
+	 * 
+	 * @return     boolean
+	 */
+	public function isUnpublished()
+	{
+		if (!in_array('state', array_keys($this->_tbl->getProperties())))
+		{
+			return false;
+		}
+		if ($this->get('state') == 0) 
+		{
+			return true;
+		}
+		return false;
+	}
+
+	/**
+	 * Has the offering started?
+	 * 
+	 * @return     boolean
+	 */
+	public function isDeleted()
+	{
+		if (!in_array('state', array_keys($this->_tbl->getProperties())))
+		{
+			return false;
+		}
+		if ($this->get('state') == 2 || $this->get('state') == -1) 
+		{
+			return true;
+		}
+		return false;
+	}
+
+	/**
+	 * Has the offering started?
 	 * 
 	 * @return     boolean
 	 */
 	public function started()
 	{
 		// If it doesn't exist or isn't published
-		if (!$this->exists())
+		if (!$this->exists()) // || !$this->isPublished()) 
 		{
 			return false;
 		}
 
-		$now = JFactory::getDate();
+		$now = date('Y-m-d H:i:s', time());
 
 		if ($this->get('publish_up') 
-		 && $this->get('publish_up') != $this->_db->getNullDate() 
+		 && $this->get('publish_up') != '0000-00-00 00:00:00' 
 		 && $this->get('publish_up') > $now) 
 		{
 			return false;
@@ -185,22 +328,22 @@ class BlogModelEntry extends \Hubzero\Model
 	}
 
 	/**
-	 * Has the publish window ended?
+	 * Has the offering ended?
 	 * 
 	 * @return     boolean
 	 */
 	public function ended()
 	{
 		// If it doesn't exist or isn't published
-		if (!$this->exists())
+		if (!$this->exists()) // || !$this->isPublished()) 
 		{
 			return true;
 		}
 
-		$now = JFactory::getDate();
+		$now = date('Y-m-d H:i:s', time());
 
 		if ($this->get('publish_down') 
-		 && $this->get('publish_down') != $this->_db->getNullDate() 
+		 && $this->get('publish_down') != '0000-00-00 00:00:00' 
 		 && $this->get('publish_down') <= $now) 
 		{
 			return true;
@@ -210,7 +353,7 @@ class BlogModelEntry extends \Hubzero\Model
 	}
 
 	/**
-	 * Check if the entry is available
+	 * Check if the offering is available
 	 * 
 	 * @return     boolean
 	 */
@@ -244,25 +387,19 @@ class BlogModelEntry extends \Hubzero\Model
 	{
 		if (!isset($this->_creator) || !is_object($this->_creator))
 		{
-			$this->_creator = Hubzero_User_Profile::getInstance($this->get('created_by'));
+			$this->_creator = JUser::getInstance($this->get('created_by'));
 		}
-		if ($property && $this->_creator instanceof Hubzero_User_Profile)
+		if ($property && is_a($this->_creator, 'JUser'))
 		{
-			$property = ($property == 'id') ? 'uidNumber' : $property;
-			if ($property == 'picture')
-			{
-				return $this->_creator->getPicture();
-			}
 			return $this->_creator->get($property);
 		}
 		return $this->_creator;
 	}
 
 	/**
-	 * Set and get a specific comment
+	 * Set and get a specific offering
 	 * 
-	 * @param      integer $id ID of specific comment to fetch
-	 * @return     object BlogModelComment
+	 * @return     void
 	 */
 	public function comment($id=null)
 	{
@@ -290,16 +427,17 @@ class BlogModelEntry extends \Hubzero\Model
 	}
 
 	/**
-	 * Get a list or count of comments
+	 * Get a list of categories for a forum
+	 *   Accepts either a numeric array index or a string [id, name]
+	 *   If index, it'll return the entry matching that index in the list
+	 *   If string, it'll return either a list of IDs or names
 	 * 
-	 * @param      string  $rtrn    Data format to return
-	 * @param      array   $filters Filters to apply to data fetch
-	 * @param      boolean $clear   Clear cached data?
-	 * @return     mixed
+	 * @param      mixed $idx Index value
+	 * @return     array
 	 */
-	public function comments($rtrn='list', $filters=array(), $clear = false)
+	public function comments($rtrn='list', $filters=array())
 	{
-		$tbl = new BlogTableComment($this->_db);
+		$tbl = new BlogComment($this->_db);
 
 		if (!isset($filters['entry_id']))
 		{
@@ -313,54 +451,50 @@ class BlogModelEntry extends \Hubzero\Model
 		switch (strtolower($rtrn))
 		{
 			case 'count':
-				if (!isset($this->_comments_count) || !is_numeric($this->_comments_count) || $clear)
+				if (!isset($this->_comments_count) || !is_numeric($this->_comments_count))
 				{
 					$this->_comments_count = 0;
-
+					//$this->_comments_count = (int) $tbl->count($filters);
 					if (!$this->_comments) 
 					{
 						$c = $this->comments('list', $filters);
 					}
-					foreach ($this->_comments as $com)
-					{
-						$this->_comments_count++;
-						if ($com->replies()) 
+						foreach ($this->_comments as $com)
 						{
-							foreach ($com->replies() as $rep)
+							$this->_comments_count++;
+							if ($com->replies()) 
 							{
-								$this->_comments_count++;
-								if ($rep->replies()) 
+								foreach ($com->replies() as $rep)
 								{
-									$this->_comments_count += $rep->replies()->total();
+									$this->_comments_count++;
+									if ($rep->replies()) 
+									{
+										$this->_comments_count += $rep->replies()->total();
+									}
 								}
 							}
 						}
 					}
-				}
 				return $this->_comments_count;
 			break;
 
 			case 'list':
 			case 'results':
 			default:
-				if (!($this->_comments instanceof \Hubzero\ItemList) || $clear)
+				if (!isset($this->_comments) || !is_a($this->_comments, 'BlogModelIterator'))
 				{
 					if ($results = $tbl->getAllComments($this->get('id')))
 					{
 						foreach ($results as $key => $result)
 						{
 							$results[$key] = new BlogModelComment($result);
-							$results[$key]->set('option', $this->_adapter()->get('option'));
-							$results[$key]->set('scope', $this->_adapter()->get('scope'));
-							$results[$key]->set('alias', $this->_adapter()->get('alias'));
-							$results[$key]->set('path', $this->_adapter()->get('path'));
 						}
 					}
 					else
 					{
 						$results = array();
 					}
-					$this->_comments = new \Hubzero\ItemList($results);
+					$this->_comments = new BlogModelIterator($results);
 				}
 				return $this->_comments;
 			break;
@@ -368,49 +502,57 @@ class BlogModelEntry extends \Hubzero\Model
 	}
 
 	/**
-	 * Get tags on an entry
+	 * Check if the current user is enrolled
 	 * 
-	 * @param      string  $what  Data format to return (string, array, cloud)
-	 * @param      integer $admin Get admin tags? 0=no, 1=yes
-	 * @return     mixed
+	 * @return     boolean
 	 */
-	public function tags($what='cloud', $admin=0)
+	public function tags($what='cloud')
 	{
-		if (!$this->exists())
-		{
-			switch (strtolower($what))
-			{
-				case 'array':
-					return array();
-				break;
+		$bt = new BlogTags($this->_db);
 
-				case 'string':
-				case 'cloud':
-				case 'html':
-				default:
-					return '';
-				break;
-			}
+		$tags = null;
+
+		$what = strtolower(trim($what));
+		switch ($what)
+		{
+			case 'array':
+				$tags = $bt->get_tags_on_object($this->get('id'), 0, 0);
+			break;
+
+			case 'string':
+				$tags = $bt->get_tag_string($this->get('id'));
+			break;
+
+			case 'cloud':
+				$tags = $bt->get_tag_cloud(0, 0, $this->get('id'));
+			break;
 		}
 
-		$cloud = new BlogModelTags($this->get('id'));
-
-		return $cloud->render($what, array('admin' => $admin));
+		return $tags; 
 	}
 
 	/**
 	 * Tag the entry
 	 * 
-	 * @param      string  $tags    Tags to apply
-	 * @param      integer $user_id ID of tagger
-	 * @param      integer $admin   Tag as admin? 0=no, 1=yes
 	 * @return     boolean
 	 */
-	public function tag($tags=null, $user_id=0, $admin=0)
+	public function tag($tags=null, $user_id=0)
 	{
-		$cloud = new BlogModelTags($this->get('id'));
+		$bt = new BlogTags($this->_db);
 
-		return $cloud->setTags($tags, $user_id, $admin);
+		if (!$user_id)
+		{
+			$juser = JFactory::getUser();
+			$user_id = $juser->get('id');
+		}
+
+		return $bt->tag_object(
+			$user_id, 
+			$this->get('id'), 
+			trim($tags), 
+			1, 
+			1
+		);
 	}
 
 	/**
@@ -449,82 +591,107 @@ class BlogModelEntry extends \Hubzero\Model
 	 * Generate and return various links to the entry
 	 * Link will vary depending upon action desired, such as edit, delete, etc.
 	 * 
-	 * @param      string $type   The type of link to return
-	 * @param      mixed  $params String or array of extra params to append
-	 * @return     string
+	 * @param      string $type The type of link to return
+	 * @return     boolean
 	 */
-	public function link($type='', $params=null)
+	public function link($type='')
 	{
-		return $this->_adapter()->build($type, $params);
-	}
-
-	/**
-	 * Gets a property of the adapter's object (e.g., a group, a member)
-	 * 
-	 * @param      string $property Property to get
-	 * @return     string
-	 */
-	public function item($property=null)
-	{
-		return $this->_adapter()->item($property);
-	}
-
-	/**
-	 * Return the adapter for this entry's scope,
-	 * instantiating it if it doesn't already exist
-	 * 
-	 * @return    object
-	 */
-	private function _adapter()
-	{
-		if (!$this->_adapter)
+		if (!isset($this->_base))
 		{
-			$scope = strtolower($this->get('scope'));
-			if ($scope == 'group')
+			switch (strtolower($this->get('scope')))
 			{
-				$this->set('scope_id', $this->get('group_id'));
-			}
-			else if ($scope == 'member')
-			{
-				$this->set('scope_id', $this->get('created_by'));
-			}
+				case 'group':
+					$group = Hubzero_Group::getInstance($this->get('group_id'));
+					$this->_base = 'index.php?option=com_groups&cn=' . $group->get('cn') . '&active=blog';
+				break;
 
-			$cls = 'BlogModelAdapter' . ucfirst($scope);
+				case 'member':
+					$this->_base = 'index.php?option=com_members&id=' . $this->get('created_by') . '&active=blog';
+				break;
 
-			if (!class_exists($cls))
-			{
-				$path = dirname(__FILE__) . '/adapters/' . $scope . '.php';
-				if (!is_file($path))
-				{
-					throw new \InvalidArgumentException(JText::sprintf('Invalid scope of "%s"', $scope));
-				}
-				include_once($path);
+				case 'site':
+				default:
+					$this->_base = 'index.php?option=com_blog';
+				break;
 			}
-
-			$this->_adapter = new $cls($this->get('scope_id'));
-			$this->_adapter->set('publish_up', $this->get('publish_up'));
-			$this->_adapter->set('id', $this->get('id'));
-			$this->_adapter->set('alias', $this->get('alias'));
 		}
-		return $this->_adapter;
+		$link = $this->_base;
+
+		// If it doesn't exist or isn't published
+		switch (strtolower($type))
+		{
+			case 'edit':
+				if (strtolower($this->get('scope')))
+				{
+					$link .= '&action=edit&entry=' . $this->get('id');
+				}
+				else 
+				{
+					$link .= '&task=edit&entry=' . $this->get('id');
+				}
+			break;
+
+			case 'delete':
+				if (strtolower($this->get('scope')))
+				{
+					$link .= '&action=delete&entry=' . $this->get('id');
+				}
+				else 
+				{
+					$link .= '&task=delete&entry=' . $this->get('id');
+				}
+			break;
+
+			case 'comments':
+				if (strtolower($this->get('scope')) == 'group')
+				{
+					$link .= '&scope=';
+				}
+				else
+				{
+					$link .= '&task=';
+				}
+				$link .= JHTML::_('date', $this->get('publish_up'), BLOG_DATE_YEAR, BLOG_DATE_TIMEZONE) . '/';
+				$link .= JHTML::_('date', $this->get('publish_up'), BLOG_DATE_MONTH, BLOG_DATE_TIMEZONE) . '/';
+				$link .= $this->get('alias');
+				$link .= '#comments';
+			break;
+
+			case 'permalink':
+			default:
+				if (strtolower($this->get('scope')) == 'group')
+				{
+					$link .= '&scope=';
+				}
+				else
+				{
+					$link .= '&task=';
+				}
+				$link .= JHTML::_('date', $this->get('publish_up'), BLOG_DATE_YEAR, BLOG_DATE_TIMEZONE) . '/';
+				$link .= JHTML::_('date', $this->get('publish_up'), BLOG_DATE_MONTH, BLOG_DATE_TIMEZONE) . '/';
+				$link .= $this->get('alias');
+			break;
+		}
+
+		return $link;
 	}
 
 	/**
 	 * Return a formatted timestamp
 	 * 
-	 * @param      string $as What format to return
-	 * @return     string
+	 * @param      string $as What data to return
+	 * @return     boolean
 	 */
 	public function published($as='')
 	{
 		switch (strtolower($as))
 		{
 			case 'date':
-				return JHTML::_('date', $this->get('publish_up'), JText::_('DATE_FORMAT_HZ1'));
+				return JHTML::_('date', $this->get('publish_up'), BLOG_DATE_FORMAT, BLOG_DATE_TIMEZONE);
 			break;
 
 			case 'time':
-				return JHTML::_('date', $this->get('publish_up'), JText::_('TIME_FORMAT_HZ1'));
+				return JHTML::_('date', $this->get('publish_up'), BLOG_TIME_FORMAT, BLOG_DATE_TIMEZONE);
 			break;
 
 			default:
@@ -534,11 +701,11 @@ class BlogModelEntry extends \Hubzero\Model
 	}
 
 	/**
-	 * Get the content of the entry
+	 * Get the state of the entry as either text or numerical value
 	 * 
 	 * @param      string  $as      Format to return state in [text, number]
 	 * @param      integer $shorten Number of characters to shorten text to
-	 * @return     string
+	 * @return     mixed String or Integer
 	 */
 	public function content($as='parsed', $shorten=0)
 	{
@@ -547,41 +714,69 @@ class BlogModelEntry extends \Hubzero\Model
 		switch ($as)
 		{
 			case 'parsed':
-				if (($content = $this->get('content_parsed')))
+				if ($this->get('content_parsed'))
 				{
-					if ($shorten)
+					return $this->get('content_parsed');
+				}
+
+				$paramsClass = 'JParameter';
+				if (version_compare(JVERSION, '1.6', 'ge'))
+				{
+					$paramsClass = 'JRegistry';
+				}
+
+				switch ($this->get('scope'))
+				{
+					case 'group':
+						$option = 'com_groups';
+						$plg = JPluginHelper::getPlugin('groups', 'blog');
+						$config = new $paramsClass($plg->params);
+						$path = str_replace('{{gid}}', $this->get('scope_id'), $config->get('uploadpath', '/site/groups/{{gid}}/blog'));
+						$scope = $this->get('scope_id') . '/blog';
+					break;
+
+					case 'member':
+						ximport('Hubzer_View_Helper_Html');
+						$option = 'com_members';
+						$plg = JPluginHelper::getPlugin('members', 'blog');
+						$config = new $paramsClass($plg->params);
+						$path = str_replace('{{uid}}', Hubzero_View_Helper_Html::niceidformat($this->get('created_by')), $config->get('uploadpath', '/site/members/{{uid}}/blog'));
+						$scope = $this->get('created_by') . '/blog';
+					break;
+
+					case 'site':
+					default:
+						$option = 'com_blog';
+						$config = JComponentHelper::getParams($option);
+						$path = $config->get('uploadpath', '/site/blog');
+						$scope = $this->get('scope');
+					break;
+				}
+
+				$p =& Hubzero_Wiki_Parser::getInstance();
+
+				$wikiconfig = array(
+					'option'   => $option,
+					'scope'    => $scope, //$this->get('scope')
+					'pagename' => $this->get('alias'),
+					'pageid'   => 0, //$this->get('id'),
+					'filepath' => $path,
+					'domain'   => ''
+				);
+
+				$this->set('content_parsed', $p->parse(stripslashes($this->get('content')), $wikiconfig));
+
+				if ($shorten)
+				{
+					$content = Hubzero_View_Helper_Html::shortenText($this->get('content_parsed'), $shorten, 0, 0);
+					if (substr($content, -7) == '&#8230;') 
 					{
-						$content = Hubzero_View_Helper_Html::shortenText($content, $shorten, 0, 0);
-						if (substr($content, -7) == '&#8230;') 
-						{
-							$content .= '</p>';
-						}
+						$content .= '</p>';
 					}
 					return $content;
 				}
 
-				$scope  = JHTML::_('date', $this->get('publish_up'), 'Y') . '/';
-				$scope .= JHTML::_('date', $this->get('publish_up'), 'm');
-
-				$config = array(
-					'option'   => $this->_adapter()->get('option'),
-					'scope'    => $this->_adapter()->get('scope') . '/' . $scope,
-					'pagename' => $this->get('alias'),
-					'pageid'   => 0, //$this->get('id'),
-					'filepath' => $this->_adapter()->get('path'),
-					'domain'   => ''
-				);
-
-				$content = $this->importPlugin('hubzero')->trigger('onWikiParseText', array(
-					stripslashes($this->get('content')), 
-					$config,  // options
-					true,     // full parse
-					true      // new parser?
-				));
-
-				$this->set('content_parsed', implode('', $content));
-
-				return $this->content($as, $shorten);
+				return $this->get('content_parsed');
 			break;
 
 			case 'clean':
@@ -595,16 +790,57 @@ class BlogModelEntry extends \Hubzero\Model
 
 			case 'raw':
 			default:
-				$content = stripslashes($this->get('content'));
-				if ($shorten)
-				{
-					$content = Hubzero_View_Helper_Html::shortenText($content, $shorten, 0, 1);
-				}
-				return $content;
+				return $this->get('content');
 			break;
 		}
 	}
 
+	/**
+	 * Check if the course exists
+	 * 
+	 * @param      mixed $idx Index value
+	 * @return     array
+	 */
+	public function bind($data=null)
+	{
+		return $this->_tbl->bind($data);
+	}
+
+	/**
+	 * Store changes to this offering
+	 *
+	 * @param     boolean $check Perform data validation check?
+	 * @return    boolean False if error, True on success
+	 */
+	public function store($check=true)
+	{
+		// Ensure we have a database to work with
+		if (empty($this->_db))
+		{
+			return false;
+		}
+
+		// Validate data?
+		if ($check)
+		{
+			// Is data valid?
+			if (!$this->_tbl->check())
+			{
+				$this->setError($this->_tbl->getError());
+				return false;
+			}
+		}
+
+		// Attempt to store data
+		if (!$this->_tbl->store())
+		{
+			$this->setError($this->_tbl->getError());
+			return false;
+		}
+
+		return true;
+	}
+
 	/**
 	 * Check a user's authorization
 	 * 
@@ -613,7 +849,7 @@ class BlogModelEntry extends \Hubzero\Model
 	 */
 	public function access($action='view')
 	{
-		if (!$this->params->get('access-check-done', false))
+		if (!$this->_authorized)
 		{
 			// Set NOT viewable by default
 			// We need to ensure the forum is published first
@@ -627,10 +863,13 @@ class BlogModelEntry extends \Hubzero\Model
 			$juser = JFactory::getUser();
 			if ($juser->get('guest'))
 			{
-				$this->params->set('access-check-done', true);
+				$this->_authorized = true;
 			}
 			else
 			{
+				// Anyone logged in can create a forum
+				//$this->params->set('access-create-entry', true);
+
 				// Check if they're a site admin
 				if (version_compare(JVERSION, '1.6', 'lt'))
 				{
@@ -658,7 +897,27 @@ class BlogModelEntry extends \Hubzero\Model
 				if (!$this->params->get('access-admin-entry') 
 				 && !$this->params->get('access-manage-entry'))
 				{
-					// Was the entry created by the current user?
+					// Does the forum exist?
+					/*if (!$this->exists())
+					{
+						// Give editing access if the blog doesn't exist
+						// i.e., it's a new forum
+						switch ($this->get('scope'))
+						{
+							case 'site':
+							break;
+							
+							case 'member':
+							break;
+						}
+						$this->params->set('access-view-entry', true);
+						$this->params->set('access-delete-entry', true);
+						$this->params->set('access-edit-entry', true);
+						$this->params->set('access-edit-state-entry', true);
+						$this->params->set('access-edit-own-entry', true);
+					}
+					// Check if they're the forum creator or forum manager
+					else*/
 					if ($this->get('created_by') == $juser->get('id')) 
 					{
 						// Give full access
@@ -671,7 +930,7 @@ class BlogModelEntry extends \Hubzero\Model
 					}
 				}
 
-				$this->params->set('access-check-done', true);
+				$this->_authorized = true;
 			}
 		}
 		return $this->params->get('access-' . strtolower($action) . '-entry');
