@@ -452,15 +452,23 @@ class CoursesModelSection extends CoursesModelAbstract
 		{
 			$role_id = $role->get('id');
 		}
+		if (!$this->get('course_id'))
+		{
+			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'offering.php');
+			$offering = CoursesModelOffering::getInstance($this->get('offering_id'));
+			$this->set('course_id', $offering->get('course_id'));
+		}
 		foreach ($data as $result)
 		{
-			$user_id = $this->_userId($result);
+			$user_id = (int) $this->_userId($result);
 
 			// Create the entry
-			$model = new CoursesModelMember($result, null, null, $this->get('id'));
-			$model->set('role_id', $role_id);
+			$model = CoursesModelMember::getInstance($user_id, $this->get('course_id'), $this->get('offering_id'), $this->get('id'));
+			$model->set('user_id', $user_id);
+			$model->set('course_id', $this->get('course_id'));
 			$model->set('offering_id', $this->get('offering_id'));
 			$model->set('section_id', $this->get('id'));
+			$model->set('role_id', $role_id);
 			if ($role->get('alias') == 'student')
 			{
 				$model->set('student', 1);
