@@ -8,6 +8,16 @@ $record = $resp->getAnswers();
 	<h2>Results: <?= $this->title ?></h2>
 </div>
 
+<div id="content-header-extra">
+	<ul>
+		<li>
+			<a class="icon-back back btn" href="<?php echo JRoute::_($this->base); ?>">
+			<?php echo JText::_('Back to course'); ?>
+			</a>
+		</li>
+	</ul>
+</div>
+
 <div class="main section">
 	<p>Completed <?= date('r', strtotime($resp->getEndTime())); ?></p>
 	<p>Score <strong><?= $record['summary']['score'] ?>%</strong></p>
@@ -19,7 +29,7 @@ $record = $resp->getAnswers();
 		You are allowed <strong><?= $this->dep->getAllowedAttempts() ?></strong> attempts.
 		This was your <strong><?= FormHelper::toOrdinal((int)$attempt) ?></strong> attempt.
 		<? if ($this->dep->getAllowedAttempts() > $attempt) : ?>
-			<a href="<?= JRoute::_('/courses/form/complete?crumb='.$this->dep->getCrumb().'&attempt='.((int)$attempt+1)) ?>">Take your <?= FormHelper::toOrdinal((int)$attempt+1) ?> attempt</a>
+			<a href="<?= JRoute::_($this->base . '&task=form.complete&crumb='.$this->dep->getCrumb().'&attempt='.((int)$attempt+1)) ?>">Take your <?= FormHelper::toOrdinal((int)$attempt+1) ?> attempt</a>
 		<? endif; ?>
 	<? endif; ?>
 </div>
\ No newline at end of file
