@@ -52,14 +52,6 @@ function task_file($db_id)
 	}
 }
 
-
-function task_stream_file($db_id)
-{
-	$hash = JRequest::getVar('hash');
-	stream_file($hash);
-	exit;
-}
-
 function task_view($db_id)
 {
 	global $dv_conf;
@@ -67,11 +59,6 @@ function task_view($db_id)
 
 	$dd = get_dd($db_id);
 
-	if (!$dd) {
-		JError::raiseError('404', 'Invalid DataView', 'Invalid DataView');
-		return;
-	}
-
 	if (!authorize($dd)) {
 		print ('<br /><p class="warning">Sorry, you are not authorized to view this page.</p>');
 		return;
@@ -83,6 +70,7 @@ function task_view($db_id)
 		require_once ($file);
 	}
 
+
 	pathway($dd);
 
 	$file = (JPATH_COMPONENT.DS."view".DS."$view.php");
@@ -126,8 +114,9 @@ function task_data($db_id)
 function authorize($dd)
 {
 	global $dv_conf;
-
-	$juser = JFactory::getUser();
+	ximport('Hubzero_Group');
+	ximport('Hubzero_User_Helper');
+	$juser =& JFactory::getUser();
 
 	if (isset($dd['acl']['allowed_users']) && (is_array($dd['acl']['allowed_users']) || $dd['acl']['allowed_users'] === false || $dd['acl']['allowed_users'] == 'registered')) {
 		$dv_conf['acl']['allowed_users'] = $dd['acl']['allowed_users'];
@@ -160,7 +149,6 @@ function authorize($dd)
 	}
 	
 	if ($dv_conf['acl']['allowed_groups'] !== false && is_array($dv_conf['acl']['allowed_groups']) && !$juser->get('guest')) {
-		ximport('Hubzero_User_Helper');
 		$groups = Hubzero_User_Helper::getGroups($juser->get('id'));
 		if ($groups && count($groups)) {
 			foreach ($groups as $g) {
