@@ -57,8 +57,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 			JRequest::setVar('task', 'view');
 		}
 
-		$parts = explode('/', $_SERVER['REQUEST_URI']);
-		$file = array_pop($parts);
+		$file = array_pop(explode('/', $_SERVER['REQUEST_URI']));
 
 		if (substr(strtolower($file), 0, 5) == 'image' 
 		 || substr(strtolower($file), 0, 4) == 'file') 
@@ -163,8 +162,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 				FROM #__xprofiles AS xp 
 				INNER JOIN #__users u ON u.id = xp.uidNumber AND u.block = 0
 				WHERE LOWER(xp.name) LIKE '%" . $this->database->getEscaped($filters['search']) . "%' AND xp.emailConfirmed>0 $restrict 
-				ORDER BY xp.name ASC
-				LIMIT " . $filters['start'] . "," . $filters['limit'];
+				ORDER BY xp.name ASC";
 
 		$this->database->setQuery($query);
 		$rows = $this->database->loadObjectList();
@@ -224,14 +222,12 @@ class MembersControllerProfiles extends Hubzero_Controller
 
 		$this->view->title = JText::_('MEMBERS');
 
-		$this->view->contribution_counting = $this->config->get('contribution_counting', true);
-
 		// Set the page title
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		// Set the document pathway
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
@@ -267,8 +263,6 @@ class MembersControllerProfiles extends Hubzero_Controller
 		// Get configuration
 		$jconfig = JFactory::getConfig();
 
-		$this->view->contribution_counting = $this->config->get('contribution_counting', true);
-
 		// Incoming
 		$this->view->filters = array();
 		$this->view->filters['limit']  = JRequest::getVar('limit', $jconfig->getValue('config.list_limit'), 'request');
@@ -278,23 +272,6 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$this->view->filters['search'] = JRequest::getVar('search', '');
 		$this->view->filters['index']  = JRequest::getWord('index', '');
 
-		if ($this->view->contribution_counting == false)
-		{
-			if ($this->view->filters['show'] = 'contributors')
-			{
-				$this->view->filters['show'] = 'members';
-			}
-
-			if ($this->view->filters['sortby'] == 'contributions')
-			{
-				$this->view->filters['sortby'] = 'name';
-			}
-		}
-		else
-		{
-			$this->view->filters['contributions'] = 0;
-		}
-
 		// Build the page title
 		if ($this->view->filters['show'] == 'contributors') 
 		{
@@ -313,11 +290,11 @@ class MembersControllerProfiles extends Hubzero_Controller
 		}
 
 		// Set the page title
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		// Set the document pathway
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
@@ -351,7 +328,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		// Initiate a contributor object
 		$c = new MembersProfile($this->database);
 
-		$cache = JFactory::getCache('callback');
+		$cache =& JFactory::getCache('callback');
 		$cache->setCaching(1);
 		$cache->setLifeTime(intval($this->config->get('cache_time', 15)));
 		$stats = $cache->call(array($this, 'stats'));
@@ -369,11 +346,11 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$this->view->rows = $c->getRecords($this->view->filters, $admin);
 		
 		//get newly registered members (past day)
-		//$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . JFactory::getDate(strtotime('-1 DAY'))->toSql() . "'");
+		//$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . date("Y-m-d H:i:s", strtotime('-1 DAY')) . "'");
 		$this->view->past_day_members = $stats->past_day_members; //$this->database->loadResult();
 		
 		//get newly registered members (past month)
-		//$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . JFactory::getDate(strtotime('-1 MONTH'))->toSql() . "'");
+		//$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . date("Y-m-d H:i:s", strtotime('-1 MONTH')) . "'");
 		$this->view->past_month_members = $stats->past_month_members; //$this->database->loadResult();
 		
 		// Initiate paging
@@ -417,11 +394,11 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$stats->total_public_members = $c->getCount(array('show' => '', 'authorized' => false), false);
 
 		//get newly registered members (past day)
-		$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . JFactory::getDate(strtotime('-1 DAY'))->toSql() . "'");
+		$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . date("Y-m-d H:i:s", strtotime('-1 DAY')) . "'");
 		$stats->past_day_members = $this->database->loadResult();
 
 		//get newly registered members (past month)
-		$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . JFactory::getDate(strtotime('-1 MONTH'))->toSql() . "'");
+		$this->database->setQuery("SELECT COUNT(*) FROM #__xprofiles WHERE registerDate > '" . date("Y-m-d H:i:s", strtotime('-1 MONTH')) . "'");
 		$stats->past_month_members = $this->database->loadResult();
 
 		return $stats;
@@ -462,7 +439,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$this->view->title  = JText::_(strtoupper($this->_name));
 		$this->view->title .= ($this->_task) ? ': ' . JText::_(strtoupper($this->_task)) : '';
 
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
@@ -481,7 +458,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 
 		// Get plugins
 		JPluginHelper::importPlugin('members');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		// Ensure we have an ID
 		if (!$id) 
@@ -620,11 +597,11 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$title  = JText::_(strtoupper($this->_name));
 		$title .= ($this->_task) ? ': ' . JText::_(strtoupper($this->_task)) : '';
 
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($title);
 
 		// Set the pathway
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
@@ -837,7 +814,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		// Redirect user back to main account page
 		$return = base64_decode(JRequest::getVar('return', '',  'method', 'base64'));
 		$this->_redirect = $return ? $return : JRoute::_('index.php?option=' . $this->_option . '&id=' . $id);
-		$session = JFactory::getSession();
+		$session =& JFactory::getSession();
 
 		// Redirect user back to main account page
 		if (JRequest::getInt('no_html', 0))
@@ -855,7 +832,9 @@ class MembersControllerProfiles extends Hubzero_Controller
 		{
 			if ($session->get('badpassword','0') || $session->get('expiredpassword','0'))
 			{
-				$this->_redirect = $this->config->get('LoginReturn', '/members/myaccount');
+				$hconfig = &JComponentHelper::getParams('com_hub');
+				$r = $hconfig->get('LoginReturn');
+				$this->_redirect = ($r) ? $r : '/members/myaccount';
 				$session->set('badpassword','0');
 				$session->set('expiredpassword','0');
 			}
@@ -873,11 +852,11 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$this->view->title  = JText::_(strtoupper($this->_name));
 		$this->view->title .= ($this->_task) ? ': ' . JText::_(strtoupper($this->_task)) : '';
 
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		// Set the pathway
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
@@ -1041,7 +1020,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		// Do we need to email admin?
 		if ($request !== null && !empty($resourcemessage)) 
 		{
-			$juri = JURI::getInstance();
+			$juri =& JURI::getInstance();
 			$jconfig = JFactory::getConfig();
 			$sitename = $jconfig->getValue('config.sitename');
 			$live_site = rtrim(JURI::base(),'/');
@@ -1131,11 +1110,11 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$this->view->title  = JText::_(strtoupper($this->_name));
 		$this->view->title .= ($this->_task) ? ': ' . JText::_(strtoupper($this->_task)) : '';
 
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		// Set the pathway
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
@@ -1289,7 +1268,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 			default:       $index = 0; break;
 		}
 
-		$hconfig = JComponentHelper::getParams('com_register');
+		$hconfig =& JComponentHelper::getParams('com_register');
 
 		$default = str_pad($default, 4, '-');
 		$configured = $hconfig->get($name);
@@ -1511,7 +1490,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		}
 
 		// Set the last modified datetime
-		$profile->set('modifiedDate', JFactory::getDate()->toSql());
+		$profile->set('modifiedDate', date('Y-m-d H:i:s', time()));
 
 		// Save the changes
 		if (!$profile->update()) 
@@ -1533,7 +1512,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		// Make sure certain changes make it back to the Joomla user table
 		if ($id > 0) 
 		{
-			$juser = JUser::getInstance($id);
+			$juser =& JUser::getInstance($id);
 			$jname = $juser->get('name');
 			$jemail = $juser->get('email');
 			if ($name != trim($jname)) 
@@ -1563,7 +1542,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		//if were declinging the terms we want to logout user and tell the javascript
 		if ($declineTOU)
 		{
-			$application = JFactory::getApplication();
+			$application =& JFactory::getApplication();
 			$application->logout();
 			echo json_encode(array('loggedout' => true));
 			return;
@@ -1594,7 +1573,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 	 */
 	private function _sendConfirmationCode($login, $email, $confirm)
 	{
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 		$juri = JURI::getInstance();
 
 		// Email subject
@@ -1635,7 +1614,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 	public function saveaccessTask()
 	{
 		// Check if they are logged in
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($this->juser->get('guest')) 
 		{
 			return false;
@@ -1683,11 +1662,11 @@ class MembersControllerProfiles extends Hubzero_Controller
 	public function activityTask()
 	{
 		// Set the page title
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle(JText::_(strtoupper($this->_name)) . ': ' . JText::_(strtoupper($this->_task)));
 
 		// Set the pathway
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
@@ -1725,7 +1704,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		$user  = array();
 		$users = array();
 
-		$sql = "SELECT s.username, s.ip, (UNIX_TIMESTAMP(UTC_TIMESTAMP()) - s.time) AS idle 
+		$sql = "SELECT s.username, s.ip, (UNIX_TIMESTAMP(NOW()) - s.time) AS idle 
 				FROM #__session AS s WHERE s.username <> '' 
 				ORDER BY username, ip, idle DESC";
 
@@ -1766,7 +1745,7 @@ class MembersControllerProfiles extends Hubzero_Controller
 		}
 
 		$guests = array();
-		$sql = "SELECT s.ip, (UNIX_TIMESTAMP(UTC_TIMESTAMP()) - s.time) AS idle 
+		$sql = "SELECT s.ip, (UNIX_TIMESTAMP(NOW()) - s.time) AS idle 
 				FROM #__session AS s WHERE s.username = '' 
 				ORDER BY ip, idle DESC";
 
