@@ -39,7 +39,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 <?php if ($this->juser->get('guest')) { ?>
 <div id="content-header-extra">
 	<ul id="useroptions">
-		<li class="last"><a class="icon-add add btn" href="<?php echo JRoute::_('index.php?option=com_register'); ?>"><?php echo JText::_('Join now!'); ?></a></li>
+		<li class="last"><a class="add btn" href="<?php echo JRoute::_('index.php?option=com_register'); ?>"><?php echo JText::_('Join now!'); ?></a></li>
 	</ul>
 </div><!-- / #content-header-extra -->
 <?php } ?>
@@ -48,10 +48,10 @@ defined('_JEXEC') or die( 'Restricted access' );
 	<div class="aside">
 		<ul>
 			<li>
-				<a href="<?php echo JRoute::_('index.php?option=com_users&view=remind'); ?>">Forgot your username?</a>
+				<a href="/user/remind">Forgot your username?</a>
 			</li>
 			<li>
-				<a href="<?php echo JRoute::_('index.php?option=com_users&view=reset'); ?>">Forgot your password?</a>
+				<a href="/user/reset">Forgot your password?</a>
 			</li>
 			<li>
 				<a class="popup" href="<?php echo JRoute::_('index.php?option=com_help&component=members'); ?>">Need Help?</a>
@@ -62,68 +62,59 @@ defined('_JEXEC') or die( 'Restricted access' );
 		</ul>
 	</div><!-- / .aside -->
 	<div class="subject">
-		<div class="grid">
-			<div class="col span6">
-				<h3>Why be a member?</h3>
-				<p>As a member, you instantly become part of a community designed
-				for you and your colleagues.  Being part of the community provides quick and easy access to share knowledge with
-				fellow researchers around the world helping you achieve more of your
-				goals.  Membership is free, get started today!</p>
-			</div><!-- / .col span6 -->
-			<div class="col span6 omega">
-				<h3>How do I become a member?</h3>
-				<p>To become a member, click on the register link at the top of the page,
-				create a username and password, and complete the rest of the form.  After
-				submitting, you will receive a confirmation email momentarily; please
-				follow the instructions within.  You are now part of the unique experience
-				that is the HUB!</p>
-			</div><!-- / .col span6 -->
-		</div><!-- / .grid -->
+		<div class="two columns first">
+			<h3>Why be a member?</h3>
+			<p>As a member, you instantly become part of a community designed
+for you and your colleagues.  Being part of the community provides quick and easy access to share knowledge with
+fellow researchers around the world helping you achieve more of your
+goals.  Membership is free, get started today!</p>
+		</div>
+		<div class="two columns second">
+			<h3>How do I become a member?</h3>
+			<p>To become a member, click on the register link at the top of the page,
+create a username and password, and complete the rest of the form.  After
+submitting, you will receive a confirmation email momentarily; please
+follow the instructions within.  You are now part of the unique experience
+that is the HUB!</p>
+		</div>
+		<div class="clear"></div>
 	</div><!-- / .subject -->
 	<div class="clear"></div>
 </div><!-- / #introduction.section -->
 
 <div class="section">
 
-	<div class="grid">
-		<div class="col span3">
-			<h2>Find members</h2>
-		</div><!-- / .col span3 -->
-		<div class="col span9 omega">
-			<div class="grid">
-				<div class="col span6">
-					<form action="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=browse'); ?>" method="get" class="search">
-						<fieldset>
-							<p>
-								<label for="gsearch">Keyword or phrase:</label>
-								<input type="text" name="search" id="gsearch" value="" />
-								<input type="submit" value="Search" />
-							</p>
-							<p>
-								Search public members. Members with private profiles do not show up in results.
-							</p>
-						</fieldset>
-					</form>
-				</div><!-- / .col span6 -->
-				<div class="col span6 omega">
-					<div class="browse">
-						<p><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=browse'); ?>">Browse the list of available members</a></p>
-						<p>A list of all public members. Members with private profiles do not show up in results.</p>
-					</div><!-- / .browse -->
-				</div><!-- / .col span6 -->
-			</div><!-- / .grid -->
-		</div><!-- / .col span9 omega -->
-	</div><!-- / .grid -->
+	<div class="four columns first">
+		<h2>Find members</h2>
+	</div><!-- / .four columns first -->
+	<div class="four columns second third fourth">
+		<div class="two columns first">
+			<form action="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=browse'); ?>" method="get" class="search">
+				<fieldset>
+					<p>
+						<label for="gsearch">Keyword or phrase:</label>
+						<input type="text" name="search" id="gsearch" value="" />
+						<input type="submit" value="Search" />
+					</p>
+					<p>
+						Search public members. Members with private profiles do not show up in results.
+					</p>
+				</fieldset>
+			</form>
+		</div><!-- / .two columns first -->
+		<div class="two columns second">
+			<div class="browse">
+				<p><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=browse'); ?>">Browse the list of available members</a></p>
+				<p>A list of all public members. Members with private profiles do not show up in results.</p>
+			</div><!-- / .browse -->
+		</div><!-- / .two columns second -->
+	</div><!-- / .four columns second third fourth -->
+	<div class="clear"></div>
 
-	<?php if ($this->contribution_counting) 
-	{
-	?>
-	<div class="grid">
-		<div class="col span3">
-			<h2>Top contributors</h2>
-		</div><!-- / .col span3 -->
-		<div class="col span9 omega">
-			<div class="grid">
+	<div class="four columns first">
+		<h2>Top contributors</h2>
+	</div><!-- / .four columns first -->
+	<div class="four columns second third fourth">
 <?php
 	$c = new MembersProfile(JFactory::getDBO());
 	
@@ -135,7 +126,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 		'public' => 1,
 		'authorized' => false
 	);
-
+	
 	if ($rows = $c->getRecords($filters, false))
 	{
 		ximport('Hubzero_User_Profile_Helper');
@@ -155,13 +146,13 @@ defined('_JEXEC') or die( 'Restricted access' );
 
 			switch ($i)
 			{
-				case 2: $cls = ''; break;
-				case 1: $cls = 'omega'; break;
+				case 2: $cls = 'third'; break;
+				case 1: $cls = 'second'; break;
 				case 0: 
-				default: $cls = ''; break;
+				default: $cls = 'first'; break;
 			}
 ?>
-		<div class="col span-half <?php echo $cls; ?>">
+		<div class="two columns <?php echo $cls; ?>">
 			<div class="contributor">
 				<p class="contributor-photo">
 					<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&id=' . $contributor->get('uidNumber')); ?>">
@@ -189,10 +180,9 @@ defined('_JEXEC') or die( 'Restricted access' );
 				<?php } ?>
 				</p>
 			</div>
-		</div><!-- / .col span-third -->
+		</div><!-- / .two columns first -->
 		<?php if ($i == 1) { ?>
-		</div><!-- / .grid -->
-		<div class="grid">
+		<div class="clear"></div>
 		<?php } ?>
 <?php
 			$i++;
@@ -205,8 +195,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 <?php
 	}
 ?>
-			</div>
-		</div><!-- / .col span9 omega -->
-	</div><!-- / .grid -->
-<?php } // div class grid ?>
+	</div><!-- / .four columns second third fourth -->
+	<div class="clear"></div>
+
 </div><!-- / .section -->
