@@ -1540,11 +1540,14 @@ class ResourcesHtml
 		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_citations' . DS . 'helpers' . DS . 'format.php');
 
 		$html  = '<p>' . JText::_('COM_RESOURCES_CITATION_INSTRUCTIONS') . '</p>' . "\n";
-		$html .= '<ul class="citations results">' . "\n";
-		$html .= "\t" . '<li>' . "\n";
-		$html .= $citations;
-		$html .= "\t" . '</li>' . "\n";
-		$html .= '</ul>' . "\n";
+		if (trim($citations))
+		{
+			$html .= '<ul class="citations results">' . "\n";
+			$html .= "\t" . '<li>' . "\n";
+			$html .= $citations;
+			$html .= "\t" . '</li>' . "\n";
+			$html .= '</ul>' . "\n";
+		}
 		if ($cite) 
 		{
 			$html .= '<ul class="citations results">' . "\n";
