@@ -45,7 +45,7 @@ class SupportControllerAbuse extends Hubzero_Controller
 	 */
 	protected function _buildPathway()
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
 		if (count($pathway->getPathWay()) <= 0) 
 		{
@@ -70,7 +70,7 @@ class SupportControllerAbuse extends Hubzero_Controller
 		$this->_title = JText::_(strtoupper($this->_option));
 		$this->_title .= ': ' . JText::_(strtoupper('REPORT_ABUSE'));
 
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->_title);
 	}
 
@@ -115,7 +115,7 @@ class SupportControllerAbuse extends Hubzero_Controller
 
 		// Load plugins
 		JPluginHelper::importPlugin('support');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		// Get the search result totals
 		$results = $dispatcher->trigger('getReportedItem', array(
@@ -199,7 +199,7 @@ class SupportControllerAbuse extends Hubzero_Controller
 		$row->report     = Hubzero_Filter::cleanXss($row->report);
 		$row->report     = nl2br($row->report);
 		$row->created_by = $this->juser->get('id');
-		$row->created    = JFactory::getDate()->toSql();
+		$row->created    = date('Y-m-d H:i:s', time());
 		$row->state      = 0;
 
 		// Check content
@@ -222,7 +222,7 @@ class SupportControllerAbuse extends Hubzero_Controller
 
 		// Get the search result totals
 		JPluginHelper::importPlugin('support');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 		$results = $dispatcher->trigger('onReportItem', array(
 			$this->view->refid,
 			$this->view->cat
@@ -231,7 +231,7 @@ class SupportControllerAbuse extends Hubzero_Controller
 		// Send notification email 
 		if ($email) 
 		{
-			$jconfig = JFactory::getConfig();
+			$jconfig =& JFactory::getConfig();
 
 			$from = array();
 			$from['name']  = $jconfig->getValue('config.sitename') . ' ' . JText::_('REPORTABUSE');
