@@ -55,11 +55,11 @@ Hubzero_Document::addComponentStylesheet($this->option, 'assets/css/conditions.c
 		<div id="page-sidebar">
 			<fieldset class="filters">
 				<label for="filter-search"><?php echo JText::_('SUPPORT_FIND'); ?>:</label>
-				<input type="text" name="search" id="filter-search" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo JText::_('Search this query'); ?>" />
+				<input type="text" name="search" id="filter-search" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="Search this query" />
 
-				<input type="hidden" name="sort" value="<?php echo $this->escape($this->filters['sort']); ?>" />
-				<input type="hidden" name="sortdir" value="<?php echo $this->escape($this->filters['sortdir']); ?>" />
-				<input type="hidden" name="show" value="<?php echo $this->escape($this->filters['show']); ?>" />
+				<input type="hidden" name="sort" value="<?php echo $this->filters['sort']; ?>" />
+				<input type="hidden" name="sortdir" value="<?php echo $this->filters['sortdir']; ?>" />
+				<input type="hidden" name="show" value="<?php echo $this->filters['show']; ?>" />
 
 				<input type="submit" value="<?php echo JText::_('GO'); ?>" />
 			</fieldset>
@@ -294,7 +294,7 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 		if (!isset($users[$row->login]))
 		{
 			//echo 'ffff';
-			$targetuser = JUser::getInstance($row->login);
+			$targetuser =& JUser::getInstance($row->login);
 			if (is_object($targetuser) && $targetuser->get('id'))
 			{
 				$users[$row->login] = $targetuser;
@@ -342,11 +342,11 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 									<?php echo $this->escape($row->name); echo ($lnk) ? ' (<a href="' . $lnk . '">' . $this->escape($row->login) . '</a>)' : ''; ?>
 								</span>
 								<span class="ticket-datetime">
-									@ <time datetime="<?php echo $row->created; ?>"><?php echo JHTML::_('date', $row->created, JFactory::getDBO()->getDateFormat()); ?></time>
+									@ <time datetime="<?php echo $row->created; ?>"><?php echo $row->created; ?></time>
 								</span>
 		<?php if ($lastcomment && $lastcomment != '0000-00-00 00:00:00') { ?>
 								<span class="ticket-activity">
-									<time datetime="<?php echo $lastcomment; ?>"><?php echo Hubzero_View_Helper_Html::timeAgo(Hubzero_View_Helper_Html::mkt(JHTML::_('date', $lastcomment, JFactory::getDBO()->getDateFormat()))); ?></time>
+									<time datetime="<?php echo $lastcomment; ?>"><?php echo Hubzero_View_Helper_Html::timeAgo(Hubzero_View_Helper_Html::mkt($lastcomment)); ?></time>
 								</span>
 		<?php } ?>
 							</p>
