@@ -68,10 +68,52 @@ class TagsControllerTags extends Hubzero_Controller
 	 */
 	public function displayTask()
 	{
-		$this->view->cloud = new TagsModelCloud();
-
+		// Instantiate a new view
+		$this->view->showsizes = 0;
 		$this->view->config = $this->config;
 
+		// Set some variables
+		$this->view->min_font_size = 1;
+		$this->view->max_font_size = 1.8;
+
+		// Find all tags
+		$t = new TagsTag($this->database);
+
+		$this->view->tags = $t->getTopTags(100);
+
+		$this->view->newtags = $t->getRecentTags(25);
+
+		// Trigger the functions that return the areas we'll be using
+		$this->view->categories = array();
+		$this->view->tagpile = array();
+
+		if ($this->view->tags) 
+		{
+			$retarr = array();
+			foreach ($this->view->tags as $tag)
+			{
+				$retarr[$tag->raw_tag] = $tag->tcount;
+			}
+			ksort($retarr);
+
+			$this->view->max_qty = max(array_values($retarr));  // Get the max qty of tagged objects in the set
+			$this->view->min_qty = min(array_values($retarr));  // Get the min qty of tagged objects in the set
+		} 
+		else 
+		{
+			$this->view->max_qty = 0;
+			$this->view->min_qty = 0;
+		}
+
+		// For ever additional tagged object from min to max, we add $step to the font size.
+		$spread = $this->view->max_qty - $this->view->min_qty;
+		if (0 == $spread) 
+		{
+			// Divide by zero
+			$spread = 1;
+		}
+		$this->view->step = ($this->view->max_font_size - $this->view->min_font_size)/($spread);
+
 		// Set the page title
 		$this->_buildTitle(null);
 
@@ -108,13 +150,6 @@ class TagsControllerTags extends Hubzero_Controller
 		// Ensure we were passed a tag
 		if (!$tagstring && !$addtag) 
 		{
-			if (JRequest::getWord('task', '', 'get'))
-			{
-				$this->setRedirect(
-					JRoute::_('index.php?option=' . $this->_option)
-				);
-				return;
-			}
 			JError::raiseError(404, JText::_('COM_TAGS_NO_TAG'));
 			return;
 		}
@@ -137,26 +172,31 @@ class TagsControllerTags extends Hubzero_Controller
 		}
 
 		// Sanitize the tag
+		$t = new TagsHandler($this->database);
+
 		$tags  = array();
 		$added = array();
 		$rt    = array();
 		foreach ($tgs as $tag)
 		{
-			// Load the tag
-			$tagobj = TagsModelTag::getInstance($tag);
+			$tag = $t->normalize_tag($tag);
 
-			if (in_array($tagobj->get('tag'), $added)) 
+			if (in_array($tag, $added)) 
 			{
 				continue;
 			}
 
-			$added[] = $tagobj->get('tag');
+			$added[] = $tag;
+
+			// Load the tag
+			$tagobj = new TagsTag($this->database);
+			$tagobj->loadTag($tag);
 
 			// Ensure we loaded the tag's info from the database
-			if ($tagobj->exists()) 
+			if ($tagobj->id) 
 			{
 				$tags[] = $tagobj;
-				$rt[]   = $tagobj->get('raw_tag');
+				$rt[]   = $tagobj->raw_tag;
 			}
 		}
 
@@ -167,9 +207,24 @@ class TagsControllerTags extends Hubzero_Controller
 			return;
 		}
 
+		// Set the page title
+		//$title .= ': ';
+		$tagname = array();
+		$tagstring = array();
+		for ($i=0, $n=count($tags); $i < $n; $i++)
+		{
+			if ($i > 0) 
+			{
+				//$title .= '+ ';
+			}
+			$tagname[] = $tags[$i]->raw_tag;
+			$tagstring[] = $tags[$i]->tag;
+			//$title .= $tags[$i]->raw_tag . ' ';
+		}
+
 		// Load plugins
 		JPluginHelper::importPlugin('tags');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		// Get configuration
 		$config = JFactory::getConfig();
@@ -230,10 +285,6 @@ class TagsControllerTags extends Hubzero_Controller
 				$s = array();
 				foreach ($this->view->results as $sql)
 				{
-					if (is_array($sql))
-					{
-						continue;
-					}
 					if (trim($sql) != '') 
 					{
 						$s[] = $sql;
@@ -276,7 +327,7 @@ class TagsControllerTags extends Hubzero_Controller
 				$cats[$i]['_sub']  = array();
 				$z = 0;
 				// Loop through each sub-category
-				foreach ($t as $s => $st)
+				foreach ($t as $s=>$st)
 				{
 					// Ensure a matching array of totals exist
 					if (is_array($totals[$i]) && !empty($totals[$i]) && isset($totals[$i][$z])) 
@@ -318,14 +369,14 @@ class TagsControllerTags extends Hubzero_Controller
 		$related = null;
 		if (count($tags) == 1) 
 		{
-			$this->view->tagstring = $tags[0]->get('tag');
+			$this->view->tagstring = $tags[0]->tag;
 		} 
 		else 
 		{
 			$tagstring = array();
 			foreach ($tags as $tag)
 			{
-				$tagstring[] = $tag->get('tag');
+				$tagstring[] = $tag->tag;
 			}
 			$this->view->tagstring = implode('+', $tagstring);
 		}
@@ -371,16 +422,13 @@ class TagsControllerTags extends Hubzero_Controller
 		$filters = array();
 		$filters['limit']  = 20;
 		$filters['start']  = 0;
-		$filters['admin']  = 0;
 		$filters['search'] = trim(JRequest::getString('value', ''));
 
 		// Create a Tag object
-		//$obj = new TagsTableTag($this->database);
-		$cloud = new TagsModelCloud();
+		$obj = new TagsTag($this->database);
 
 		// Fetch results
-		//$rows = $obj->getAutocomplete($filters);
-		$rows = $cloud->tags('list', $filters);
+		$rows = $obj->getAutocomplete($filters);
 
 		// Output search results in JSON format
 		$json = array();
@@ -388,11 +436,11 @@ class TagsControllerTags extends Hubzero_Controller
 		{
 			foreach ($rows as $row)
 			{
-				$name = str_replace("\n", '', stripslashes(trim($row->get('raw_tag'))));
+				$name = str_replace("\n", '', stripslashes(trim($row->raw_tag)));
 				$name = str_replace("\r", '', $name);
-
+	
 				$json[] = array(
-					'id'   => $row->get('tag'),
+					'id'   => $row->tag,
 					'name' => $name
 				);
 			}
@@ -413,12 +461,12 @@ class TagsControllerTags extends Hubzero_Controller
 		$app = JFactory::getApplication();
 
 		// Set the mime encoding for the document
-		$jdoc = JFactory::getDocument();
+		$jdoc =& JFactory::getDocument();
 		$jdoc->setMimeEncoding('application/rss+xml');
 
 		// Start a new feed object
 		$doc = new JDocumentFeed;
-		$params = $app->getParams();
+		$params =& $app->getParams();
 		$doc->link = JRoute::_('index.php?option=' . $this->_option);
 
 		// Incoming
@@ -432,25 +480,22 @@ class TagsControllerTags extends Hubzero_Controller
 		}
 
 		// Break the string into individual tags
-		$tgs = explode(',', $tagstring);
+		$tgs = explode(' ', $tagstring);
 
 		// Sanitize the tag
-		$tags  = array();
-		$added = array();
+		$t = new TagsHandler($this->database);
+
+		$tags = array();
 		foreach ($tgs as $tag)
 		{
+			$tag = $t->normalize_tag($tag);
+
 			// Load the tag
-			$tagobj = TagsModelTag::getInstance($tag);
-
-			if (in_array($tagobj->get('tag'), $added)) 
-			{
-				continue;
-			}
-
-			$added[] = $tagobj->get('tag');
+			$tagobj = new TagsTag($this->database);
+			$tagobj->loadTag($tag);
 
 			// Ensure we loaded the tag's info from the database
-			if ($tagobj->exists()) 
+			if ($tagobj->id) 
 			{
 				$tags[] = $tagobj;
 			}
@@ -465,7 +510,7 @@ class TagsControllerTags extends Hubzero_Controller
 
 		// Load plugins
 		JPluginHelper::importPlugin('tags');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		$areas = array();
 		$searchareas = $dispatcher->trigger('onTagAreas');
@@ -504,10 +549,6 @@ class TagsControllerTags extends Hubzero_Controller
 				$s = array();
 				foreach ($sqls as $sql)
 				{
-					if (!is_string($sql))
-					{
-						continue;
-					}
 					if (trim($sql) != '') 
 					{
 						$s[] = $sql;
@@ -541,7 +582,7 @@ class TagsControllerTags extends Hubzero_Controller
 			);
 		}
 
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 
 		// Run through the array of arrays returned from plugins and find the one that returned results
 		$rows = array();
@@ -565,7 +606,7 @@ class TagsControllerTags extends Hubzero_Controller
 			{
 				$title .= '+ ';
 			}
-			$title .= $tags[$i]->get('raw_tag') . ' ';
+			$title .= $tags[$i]->raw_tag . ' ';
 		}
 		$title = trim($title);
 		$title .= ': ' . $area;
@@ -637,12 +678,12 @@ class TagsControllerTags extends Hubzero_Controller
 
 		// Get configuration
 		$jconfig = JFactory::getConfig();
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 
 		// Incoming
-		$this->view->filters = array(
-			'admin' => 0
-		);
+		$this->view->filters = array();
+		//$this->view->filters['start']  = JRequest::getInt('limitstart', 0);
+		//$this->view->filters['search'] = urldecode(JRequest::getString('search'));
 		$this->view->filters['start'] = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.limitstart',
 			'limitstart',
@@ -659,7 +700,7 @@ class TagsControllerTags extends Hubzero_Controller
 			'sortby',
 			''
 		);
-
+		//$this->view->filters['sortby'] = JRequest::getVar('sortby', '');
 		if (!in_array($this->view->filters['sortby'], array('raw_tag', 'total')))
 		{
 			$this->view->filters['sortby'] = '';
@@ -667,11 +708,12 @@ class TagsControllerTags extends Hubzero_Controller
 
 		$this->view->total = 0;
 
-		$t = new TagsModelCloud();
+		$t = new TagsTag($this->database);
 
 		$order = JRequest::getVar('order', '');
 		if ($order == 'usage') 
 		{
+			//$limit = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
 			$limit = $app->getUserStateFromRequest(
 				$this->_option . '.' . $this->_controller . '.limit',
 				'limit',
@@ -679,19 +721,12 @@ class TagsControllerTags extends Hubzero_Controller
 				'int'
 			);
 
-			//$this->view->rows = $t->getTopTags($limit);
-			$this->view->rows = $t->tags('list', array(
-				'limit'    => $limit,
-				'admin'    => 0,
-				'sort'     => 'total',
-				'sort_Dir' => 'DESC',
-				'by'       => 'user'
-			));
+			$this->view->rows = $t->getTopTags($limit);
 		} 
 		else 
 		{
 			// Record count
-			$this->view->total = $t->tags('count', $this->view->filters);
+			$this->view->total = $t->getCount($this->view->filters);
 
 			$this->view->filters['limit'] = $app->getUserStateFromRequest(
 				$this->_option . '.' . $this->_controller . '.limit',
@@ -699,9 +734,10 @@ class TagsControllerTags extends Hubzero_Controller
 				$jconfig->getValue('config.list_limit'),
 				'int'
 			);
+			//$this->view->filters['limit'] = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
 
 			// Get records
-			$this->view->rows = $t->tags('list', $this->view->filters);
+			$this->view->rows = $t->getRecords($this->view->filters);
 
 			// Initiate paging
 			jimport('joomla.html.pagination');
@@ -722,7 +758,7 @@ class TagsControllerTags extends Hubzero_Controller
 		$this->_getStyles();
 
 		// Push scripts to the document
-		$this->_getScripts('assets/js/tags');
+		$this->_getScripts('assets/css/tags');
 
 		$this->view->config = $this->config;
 
@@ -750,7 +786,7 @@ class TagsControllerTags extends Hubzero_Controller
 	/**
 	 * Show a form for editing a task
 	 * 
-	 * @param      object $tag TagsTableTag
+	 * @param      object $tag TagsTag
 	 * @return     void
 	 */
 	public function editTask($tag=NULL)
@@ -772,7 +808,10 @@ class TagsControllerTags extends Hubzero_Controller
 		else 
 		{
 			// Incoming
-			$this->view->tag = new TagsModelTag(JRequest::getInt('id', 0, 'request'));
+			$id = JRequest::getInt('id', 0, 'request');
+
+			$this->view->tag = new TagsTag($this->database);
+			$this->view->tag->load($id);
 		}
 
 		$this->view->filters = array();
@@ -826,9 +865,6 @@ class TagsControllerTags extends Hubzero_Controller
 	 */
 	public function saveTask()
 	{
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
 		// Check that the user is authorized
 		if (!$this->config->get('access-edit-tag')) 
 		{
@@ -838,8 +874,7 @@ class TagsControllerTags extends Hubzero_Controller
 
 		$tag = JRequest::getVar('fields', array(), 'post');
 
-		// Bind incoming data
-		$row = new TagsModelTag($tag['id']);
+		$row = new TagsTag($this->database);
 		if (!$row->bind($tag)) 
 		{
 			$this->setError($row->getError());
@@ -847,14 +882,36 @@ class TagsControllerTags extends Hubzero_Controller
 			return;
 		}
 
-		// Store new content
-		if (!$row->store(true)) 
+		// Check content
+		if (!$row->check()) 
 		{
 			$this->setError($row->getError());
 			$this->editTask($row);
 			return;
 		}
 
+		// Make sure the tag doesn't already exist
+		if (!$row->id) 
+		{
+			if ($row->checkExistence()) 
+			{
+				$this->setError(JText::_('COM_TAGS_TAG_EXIST'));
+				$this->editTask($row);
+				return;
+			}
+		}
+
+		// Store new content
+		if (!$row->store()) 
+		{
+			$this->setError($row->getError());
+			$this->editTask($row);
+			return;
+		}
+
+		// Save substitutions
+		$row->saveSubstitutions($tag['substitutions']);
+
 		$limit  = JRequest::getInt('limit', 0);
 		$start  = JRequest::getInt('limitstart', 0);
 		$sortby = JRequest::getInt('sortby', '');
@@ -898,7 +955,7 @@ class TagsControllerTags extends Hubzero_Controller
 
 		// Get Tags plugins
 		JPluginHelper::importPlugin('tags');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		foreach ($ids as $id)
 		{
@@ -906,8 +963,8 @@ class TagsControllerTags extends Hubzero_Controller
 			$dispatcher->trigger('onTagDelete', array($id));
 
 			// Remove the tag
-			$tag = new TagsModelTag($id);
-			$tag->delete();
+			$tag = new TagsTag($this->database);
+			$tag->delete($id);
 		}
 
 		//get the browse filters so we can go back to previous view
@@ -931,7 +988,7 @@ class TagsControllerTags extends Hubzero_Controller
 	 */
 	protected function _buildPathway($tags=null)
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
 		if (count($pathway->getPathWay()) <= 0) 
 		{
@@ -953,8 +1010,8 @@ class TagsControllerTags extends Hubzero_Controller
 			$l = array();
 			foreach ($tags as $tag)
 			{
-				$t[] = stripslashes($tag->get('raw_tag'));
-				$l[] = $tag->get('tag');
+				$t[] = stripslashes($tag->raw_tag);
+				$l[] = $tag->tag;
 			}
 
 			$pathway->addItem(
@@ -982,11 +1039,11 @@ class TagsControllerTags extends Hubzero_Controller
 			$t = array();
 			foreach ($tags as $tag)
 			{
-				$t[] = stripslashes($tag->get('raw_tag'));
+				$t[] = stripslashes($tag->raw_tag);
 			}
 			$this->view->title .= ': ' . implode(' + ', $t);
 		}
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 	}
 
