@@ -34,7 +34,7 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Table class for tags
  */
-class TagsTableTag extends JTable
+class TagsTag extends JTable
 {
 	/**
 	 * int(11)
@@ -132,7 +132,7 @@ class TagsTableTag extends JTable
 			$this->$k = intval($oid);
 		}
 
-		$data = new TagsTableTag($this->_db);
+		$data = new TagsTag($this->_db);
 		$data->load($this->$k);
 		$comment = '';
 		if ($data->tag)
@@ -173,7 +173,7 @@ class TagsTableTag extends JTable
 		if ($result)
 		{
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
-			$log = new TagsTableLog($this->_db);
+			$log = new TagsLog($this->_db);
 			$log->log($oid, 'tag_deleted', $comment);
 		}
 
@@ -202,7 +202,7 @@ class TagsTableTag extends JTable
 		if ($result)
 		{
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'log.php');
-			$log = new TagsTableLog($this->_db);
+			$log = new TagsLog($this->_db);
 			$log->log($this->$k, $action);
 		}
 		return $result;
@@ -244,7 +244,7 @@ class TagsTableTag extends JTable
 			return null;
 		}
 
-		$to = new TagsTableObject($this->_db);
+		$to = new TagsObject($this->_db);
 		return $to->getCount($tagid);
 	}
 
@@ -258,7 +258,7 @@ class TagsTableTag extends JTable
 	 */
 	public function getUsageForObject($tagid=null, $objectid=null, $tbl=null)
 	{
-		$to = new TagsTableObject($this->_db);
+		$to = new TagsObject($this->_db);
 		return $to->getCountForObject($tagid, $objectid, $tbl);
 	}
 
@@ -353,69 +353,44 @@ class TagsTableTag extends JTable
 	 */
 	public function buildQuery($filters)
 	{
-		if (isset($filters['count']) && $filters['count']) 
-		{
-			$query = "SELECT count(DISTINCT t.id)";
-		} 
-		else 
-		{
-			$query = "SELECT DISTINCT t.id, t.tag, t.raw_tag, t.admin, 
-						(SELECT COUNT(*) FROM #__tags_object AS tt WHERE tt.tagid=t.id) AS total, 
-						(SELECT COUNT(*) FROM #__tags_substitute AS s WHERE s.tag_id=t.id) AS substitutes";
-		}
-		$tj = new TagsTableObject($this->_db);
-
-		$query .= " FROM $this->_tbl AS t";
-		if (isset($filters['by']) && $filters['by'] == 'user') 
-		{
-			$query .= " JOIN " . $tj->getTableName() . " AS tj ON t.id=tj.tagid AND t.raw_tag NOT LIKE 'tool:%' AND t.raw_tag NOT LIKE 'resource:%'";
-		}
-		else if (isset($filters['scope']) || isset($filters['scope_id'])) 
-		{
-			$query .= " JOIN " . $tj->getTableName() . " AS tj ON t.`id`=tj.`tagid`";
-		}
-
-		$where = array();
-
-		if (isset($filters['search']) && $filters['search'] != '') 
-		{
-			$query .= " LEFT JOIN #__tags_substitute AS sb ON sb.tag_id=t.id";
-			// Used to also query using unfiltered search text agains the rawtag and the tag.
-			// Figured this was safer
-			$where[] = "(LOWER(t.`raw_tag`) LIKE '" . $this->_db->getEscaped($filters['search']) . "%' OR LOWER(sb.`raw_tag`) LIKE '" . $this->_db->getEscaped($filters['search']) . "%')";
-		} 
+		$filter = '';
 		if (isset($filters['by'])) 
 		{
 			switch ($filters['by'])
 			{
-				case 'user':  $where[] = "`admin`=0"; break;
-				case 'admin': $where[] = "`admin`=1"; break;
+				case 'user':  $filter = "admin=0"; break;
+				case 'admin': $filter = "admin=1"; break;
 				case 'all':
-				default:  break;
+				default:      $filter = "";        break;
 			}
 		}
-		if (isset($filters['tagger_id']) && $filters['tagger_id']) 
-		{
-			$where[] = "tj.`taggerid`=" . $this->_db->Quote((int) $filters['tagger_id']);
-		}
-		if (isset($filters['scope']) && $filters['scope']) 
-		{
-			$where[] = "tj.`tbl`=" . $this->_db->Quote((string) $filters['scope']);
-		}
-		if (isset($filters['scope_id']) && $filters['scope_id']) 
-		{
-			$where[] = "tj.`objectid`=" . $this->_db->Quote((int) $filters['scope_id']);
-		}
-		if (isset($filters['admin']) && $filters['admin'] !== null) 
-		{
-			$where[] = "t.`admin`=" . $this->_db->Quote((int) $filters['admin']);
-		}
 
-		if (count($where) > 0)
+		if (isset($filters['count']) && $filters['count']) 
 		{
-			$query .= " WHERE " . implode(" AND ", $where);
+			$query = "SELECT count(*)";
+		} 
+		else 
+		{
+			$query = "SELECT t.id, t.tag, t.raw_tag, t.admin, (SELECT COUNT(*) FROM #__tags_object AS tt WHERE tt.tagid=t.id) AS total, (SELECT COUNT(*) FROM #__tags_substitute AS s WHERE s.tag_id=t.id) AS substitutes";
+		}
+		$query .= " FROM $this->_tbl AS t";
+		if ($filters['search']) 
+		{
+			// Used to also query using unfiltered search text agains the rawtag and the tag.
+			// Figured this was safer
+			$query .= " WHERE (LOWER(t.tag) LIKE '%" . $this->_db->getEscaped($this->normalize($filters['search'])) . "%')";
+			if ($filter) 
+			{
+				$query .= " AND $filter";
+			}
+		} 
+		else 
+		{
+			if ($filter) 
+			{
+				$query .= " WHERE $filter";
+			}
 		}
-
 		if (isset($filters['sortby']) && $filters['sortby'] != '') 
 		{
 			if ($filters['sortby'] == 'total') 
@@ -439,13 +414,8 @@ class TagsTableTag extends JTable
 				$query .= " ORDER BY t.raw_tag ASC";
 			}
 		}
-
 		if (isset($filters['limit']) && $filters['limit'] != 0  && $filters['limit'] != 'all') 
 		{
-			if (!isset($filters['start']))
-			{
-				$filters['start'] = 0;
-			}
 			$query .= " LIMIT " . $filters['start'] . "," . $filters['limit'];
 		}
 
@@ -490,7 +460,7 @@ class TagsTableTag extends JTable
 	 */
 	public function getCloud($tbl='', $state=0, $objectid=0)
 	{
-		$tj = new TagsTableObject($this->_db);
+		$tj = new TagsObject($this->_db);
 
 		$sql  = "SELECT t.tag, t.raw_tag, t.admin, COUNT(*) as count
 				FROM $this->_tbl AS t 
@@ -582,7 +552,7 @@ class TagsTableTag extends JTable
 	 */
 	public function getTopTags($limit=25, $tbl='', $order='tcount DESC', $exclude_private=1)
 	{
-		$tj = new TagsTableObject($this->_db);
+		$tj = new TagsObject($this->_db);
 
 		$sql  = "SELECT t.tag, t.raw_tag, t.admin, tj.tagid, tj.objectid, COUNT(tj.tagid) AS tcount ";
 		$sql .= "FROM $this->_tbl AS t  ";
@@ -619,7 +589,7 @@ class TagsTableTag extends JTable
 	 */
 	public function getRecentTags($limit=25, $order='taggedon DESC', $exclude_private=1)
 	{
-		$tj = new TagsTableObject($this->_db);
+		$tj = new TagsObject($this->_db);
 
 		$sql  = "SELECT t.tag, t.raw_tag, t.admin, tj.taggedon, COUNT(tj.tagid) AS tcount ";
 		$sql .= "FROM $this->_tbl AS t  ";
@@ -706,7 +676,7 @@ class TagsTableTag extends JTable
 
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'substitute.php');
 
-		$subs = new TagsTableSubstitute($this->_db);
+		$subs = new TagsSubstitute($this->_db);
 		if ($asString)
 		{
 			return $subs->getRecordString($tag_id, $offset, $limit);
@@ -737,7 +707,7 @@ class TagsTableTag extends JTable
 
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'substitute.php');
 
-		$ts = new TagsTableSubstitute($this->_db);
+		$ts = new TagsSubstitute($this->_db);
 		$subs = $ts->getRecords($tag_id);
 		if (!$subs)
 		{
@@ -757,7 +727,7 @@ class TagsTableTag extends JTable
 				continue; // Substitution already exists
 			}
 
-			$sub = new TagsTableSubstitute($this->_db);
+			$sub = new TagsSubstitute($this->_db);
 			$sub->raw_tag = trim($raw_tag);
 			$sub->tag_id  = $tag_id;
 			if ($sub->check())
@@ -778,7 +748,7 @@ class TagsTableTag extends JTable
 				$remove[] = $key;
 			}
 		}
-		$ts = new TagsTableSubstitute($this->_db);
+		$ts = new TagsSubstitute($this->_db);
 		if (count($remove) > 0)
 		{
 			if (!$ts->removeForTag($tag_id, $remove)) 
@@ -796,7 +766,7 @@ class TagsTableTag extends JTable
 		{
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'object.php');
 
-			$to = new TagsTableObject($this->_db);
+			$to = new TagsObject($this->_db);
 
 			// Move associations on tag and delete tag
 			foreach ($ids as $id)
@@ -812,7 +782,7 @@ class TagsTableTag extends JTable
 					$ts->moveSubstitutes($id->id, $tag_id);
 
 					// Delete the tag
-					$tag = new TagsTableTag($this->_db);
+					$tag = new TagsTag($this->_db);
 					$tag->delete($id->id);
 				}
 			}
