@@ -46,11 +46,11 @@ defined('_JEXEC') or die( 'Restricted access' );
 </div><!-- / #content-header-extra -->
 
 <div class="main section">
-	<form action="<?php echo JRoute::_('index.php?option=' . $this->option); ?>" method="get">
+	<form action="<?php echo JRoute::_('index.php?option=' . $this->option); //.'&tag='.$this->tagstring); ?>" method="get">
 		
 	<div class="aside">
 		<div class="container">
-		<h3><?php echo JText::_('COM_TAGS_CATEGORIES'); ?></h3>
+		<h3><?php echo JText::_('Categories'); ?></h3>
 		<?php
 		// Add the "all" category
 		$all = array(
@@ -68,12 +68,10 @@ defined('_JEXEC') or die( 'Restricted access' );
 		foreach ($cats as $cat)
 		{
 			// Only show categories that have returned search results
-			if ($cat['total'] > 0) 
-			{
+			if ($cat['total'] > 0) {
 				// If we have a specific category, prepend it to the search term
 				$blob = '';
-				if ($cat['category']) 
-				{
+				if ($cat['category']) {
 					$blob = $cat['category'];
 				}
 
@@ -87,43 +85,38 @@ defined('_JEXEC') or die( 'Restricted access' );
 
 				// Is this the active category?
 				$a = '';
-				if ($cat['category'] == $this->active) 
-				{
+				if ($cat['category'] == $this->active) {
 					$a = ' class="active"';
 
-					$app = JFactory::getApplication();
-					$pathway = $app->getPathway();
+					$app =& JFactory::getApplication();
+					$pathway =& $app->getPathway();
 					$pathway->addItem($cat['title'],'index.php?option=' . $this->option . '&tag=' . $this->tagstring . '&area=' . stripslashes($blob) . '&sort=' . $this->filters['sort']);
 				}
 
 				// Build the HTML
 				$l = "\t".'<li><a' . $a . ' href="' . $sef . '">' . $this->escape(stripslashes($cat['title'])) . ' <span class="item-count">' . $cat['total'] . '</span></a>';
 				// Are there sub-categories?
-				if (isset($cat['_sub']) && is_array($cat['_sub'])) 
-				{
+				if (isset($cat['_sub']) && is_array($cat['_sub'])) {
 					// An array for storing the HTML we make
 					$k = array();
 					// Loop through each sub-category
 					foreach ($cat['_sub'] as $subcat)
 					{
 						// Only show sub-categories that returned search results
-						if ($subcat['total'] > 0) 
-						{
+						if ($subcat['total'] > 0) {
 							// If we have a specific category, prepend it to the search term
 							$blob = '';
-							if ($subcat['category']) 
-							{
+							if ($subcat['category']) {
 								$blob = $subcat['category'];
 							}
 
 							// Is this the active category?
 							$a = '';
-							if ($subcat['category'] == $this->active) 
-							{
+							if ($subcat['category'] == $this->active) {
 								$a = ' class="active"';
 
-								$app = JFactory::getApplication();
-								$pathway = $app->getPathway();
+								$app =& JFactory::getApplication();
+								$pathway =& $app->getPathway();
 								$pathway->addItem($subcat['title'],'index.php?option='.$this->option.'&tag='.$this->tagstring.'&area='. stripslashes($blob).'&sort='.$this->filters['sort']);
 							}
 
@@ -137,8 +130,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 					}
 					// Do we actually have any links?
 					// NOTE: this method prevents returning empty list tags "<ul></ul>"
-					if (count($k) > 0) 
-					{
+					if (count($k) > 0) {
 						$l .= "\t\t".'<ul>'."\n";
 						$l .= implode( "\n", $k );
 						$l .= "\t\t".'</ul>'."\n";
@@ -150,15 +142,12 @@ defined('_JEXEC') or die( 'Restricted access' );
 		}
 		// Do we actually have any links?
 		// NOTE: this method prevents returning empty list tags "<ul></ul>"
-		if (count($links) > 0) 
-		{
+		if (count($links) > 0) {
 			// Yes - output the necessary HTML
 			$html  = '<ul>'."\n";
 			$html .= implode( "\n", $links );
 			$html .= '</ul>'."\n";
-		} 
-		else 
-		{
+		} else {
 			// No - nothing to output
 			$html = '';
 		}
@@ -166,45 +155,51 @@ defined('_JEXEC') or die( 'Restricted access' );
 
 		echo $html;
 		?>
-			<p class="info">
-				<?php echo JText::_('COM_TAGS_RESULTS_NOTE'); ?>
+			<p>
+				<strong>Note:</strong>  <?php echo JText::_('Results do not include pending, unpublished, and some private items.'); ?>
 			</p>
 		</div>
 	</div><!-- / .aside -->
 	<div class="subject">
-
+		
 		<div class="container data-entry">
-			<input class="entry-search-submit" type="submit" value="<?php echo JText::_('COM_TAGS_SEARCH'); ?>" />
+			<input class="entry-search-submit" type="submit" value="Search" />
 			<fieldset class="entry-search">
-				<?php
-				JPluginHelper::importPlugin('hubzero');
-				$tf = JDispatcher::getInstance()->trigger( 'onGetMultiEntry', array(array('tags', 'tag', 'actags','',$this->search)) );
-				?>
+<?php
+			JPluginHelper::importPlugin( 'hubzero' );
+			$dispatcher =& JDispatcher::getInstance();
+			$tf = $dispatcher->trigger( 'onGetMultiEntry', array(array('tags', 'tag', 'actags','',$this->search)) );
+?>
 				<label for="actags">
 					<?php echo JText::_('COM_TAGS_SEARCH_WITH_TAGS'); ?>
 				</label>
-				<?php if (count($tf) > 0) {
-					echo $tf[0];
-				} else { ?>
-				<input type="text" name="tag" id="actags" value="<?php echo $this->escape($this->search); ?>" />
-				<?php } ?>
+<?php if (count($tf) > 0) {
+						echo $tf[0];
+} else { ?>
+				<input type="text" name="tag" id="actags" value="<?php echo $this->search; ?>" />
+<?php } ?>
 			</fieldset>
 		</div><!-- / .container -->
-
-		<?php foreach ($this->tags as $tagobj) { ?>
-			<?php if ($tagobj->get('description') != '') { ?>
+		
+		<?php
+		if (count($this->tags) == 1) {
+			$tagobj = $this->tags[0];
+			if ($tagobj->description != '') {
+				//$tagobj->description = Hubzero_View_Helper_Html::xhtml($tagobj->description);
+		?>
 		<div class="container">
 			<div class="container-block">
 				<h4><?php echo JText::_('COM_TAGS_DESCRIPTION'); ?></h4>
 				<div class="tag-description">
-					<?php echo stripslashes($tagobj->get('description')); ?>
+					<?php echo stripslashes($tagobj->description); ?>
 					<div class="clearfix"></div>
 				</div>
 			</div>
 		</div><!-- / .container -->
-			<?php } ?>
-		<?php } ?>
-
+		<?php
+			}
+		}
+		?>
 		<div class="container">
 			<ul class="entries-menu">
 				<li>
@@ -214,8 +209,8 @@ defined('_JEXEC') or die( 'Restricted access' );
 						$sef = str_replace(' ',',',$sef);
 						$sef = str_replace('+',',',$sef);
 						echo $sef;
-					?>" title="COM_TAGS_OPT_SORT_BY_TITLE">
-						<?php echo JText::_('COM_TAGS_OPT_TITLE'); ?>
+					?>" title="Sort by title">
+						&darr; <?php echo JText::_('COM_TAGS_OPT_TITLE'); ?>
 					</a>
 				</li>
 				<li>
@@ -225,19 +220,20 @@ defined('_JEXEC') or die( 'Restricted access' );
 						$sef = str_replace(' ',',',$sef);
 						$sef = str_replace('+',',',$sef);
 						echo $sef;
-					?>" title="COM_TAGS_OPT_SORT_BY_DATE">
-						<?php echo JText::_('COM_TAGS_OPT_DATE'); ?>
+					?>" title="Sort by newest to oldest">
+						&darr; <?php echo JText::_('COM_TAGS_OPT_DATE'); ?>
 					</a>
 				</li>
+<?php /*				<li><a<?php echo ($this->filters['sort'] == '') ? ' class="active"' : ''; ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&tag='.$this->tagstring.'&area='.$this->active); ?>" title="Sort by popularity">&darr; <?php echo JText::_('Popular'); ?></a></li> */ ?>
 			</ul>
 
 			<div class="container-block">
 <?php
-$juri = JURI::getInstance();
+$juri =& JURI::getInstance();
 $foundresults = false;
 $dopaging = true;
 //$cats = $this->cats;
-$jconfig = JFactory::getConfig();
+$jconfig =& JFactory::getConfig();
 $html = '';
 $k = 0;
 if ($this->active) {
@@ -308,7 +304,7 @@ foreach ($this->results as $category)
 			if (substr($feed, 0, 1) != DS) {
 				$feed = DS.$feed;
 			}
-			$jconfig = JFactory::getConfig();
+			$jconfig =& JFactory::getConfig();
 			$live_site = rtrim(JURI::base(),'/');
 			$feed = $live_site.$feed;
 		}
@@ -339,7 +335,7 @@ foreach ($this->results as $category)
 		// Build the category HTML
 		$html .= '<h3 id="rel-'.$divid.'">';
 		if (!$dopaging) {
-			$html .= '<a href="'.JRoute::_('index.php?option='.$this->option.'&tag='.$this->tagstring.'&area='.$cats[$k]['category']).'" title="'.JText::sprintf('COM_TAGS_VIEW_ALL', $name).'">';
+			$html .= '<a href="'.JRoute::_('index.php?option='.$this->option.'&tag='.$this->tagstring.'&area='.$cats[$k]['category']).'" title="'.JText::_('View all items in &quot;'.$name.'&quot;').'">';
 		}
 		$html .= $this->escape(stripslashes($name)).' <span>('.$num.$total.')</span> ';
 		if (!$dopaging) {
@@ -385,8 +381,7 @@ foreach ($this->results as $category)
 		}
 		$html .= '</ol>'."\n";
 		// Initiate paging if we we're displaying an active category
-		if (!$dopaging) 
-		{
+		if (!$dopaging) {
 			$html .= '<p class="moreresults">'.JText::sprintf('COM_TAGS_TOTAL_RESULTS_FOUND',$amt);
 			// Add a "more" link if necessary
 			$ttl = 0;
@@ -402,8 +397,8 @@ foreach ($this->results as $category)
 				$sef = JRoute::_('index.php?option='.$this->option.'&tag='.$this->tagstring.'&area='. urlencode(stripslashes($cats[$k]['category'])));
 				$html .= ' <span>|</span> <a href="'.$sef.'">'.JText::_('COM_TAGS_SEE_MORE_RESULTS').' &rarr;</a>';
 			}
-			$html .= '</p>'."\n\n";
 		}
+		$html .= '</p>'."\n\n";
 		$html .= '</div><!-- / #'.$divid.' -->'."\n";
 	}
 	$k++;
@@ -414,22 +409,22 @@ if (!$foundresults) {
 echo $html;
 ?>
 			</div><!-- / .container-block -->
-			<?php
-			if ($dopaging) {
-				jimport('joomla.html.pagination');
-				$pageNav = new JPagination(
-					$this->total, 
-					$this->filters['start'], 
-					$this->filters['limit']
-				);
+<?php
+if ($dopaging) {
+	jimport('joomla.html.pagination');
+	$pageNav = new JPagination(
+		$this->total, 
+		$this->filters['start'], 
+		$this->filters['limit']
+	);
 
-				$pageNav->setAdditionalUrlParam('task', '');
-				$pageNav->setAdditionalUrlParam('tag', $this->tagstring);
-				$pageNav->setAdditionalUrlParam('active', $this->active);
-				$pageNav->setAdditionalUrlParam('sort', $this->filters['sort']);
-				echo $pageNav->getListFooter() . '<div class="clearfix"></div>';
-			}
-			?>
+	$pageNav->setAdditionalUrlParam('task', 'view');
+	$pageNav->setAdditionalUrlParam('tag', $this->tagstring);
+	$pageNav->setAdditionalUrlParam('active', $this->active);
+	$pageNav->setAdditionalUrlParam('sort', $this->filters['sort']);
+	echo $pageNav->getListFooter() . '<div class="clearfix"></div>';
+}
+?>
 		</div><!-- / .container -->
 	</div><!-- / .subject -->
 	<div class="clear"></div>
