@@ -58,7 +58,7 @@ class ToolsControllerScreenshots extends Hubzero_Controller
 		$this->_authorize();
 
 		// Load the com_resources component config
-		$rconfig = JComponentHelper::getParams('com_resources');
+		$rconfig =& JComponentHelper::getParams('com_resources');
 		$this->rconfig = $rconfig;
 
 		parent::execute();
@@ -194,11 +194,11 @@ class ToolsControllerScreenshots extends Hubzero_Controller
 		$this->view->shot = $ss->getScreenshot($this->view->file, $pid, $vid);
 
 		// Get the app
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 
 		// Set the page title
 		$this->view->title = JText::_(strtoupper($this->_name)) . ': ' . JText::_('COM_TOOLS_TASK_EDIT_SS');
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		$this->view->pid = $pid;
@@ -470,7 +470,7 @@ class ToolsControllerScreenshots extends Hubzero_Controller
 		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path)) 
+			if (!JFolder::create($path, 0777)) 
 			{
 				$this->setError(JText::_('COM_TOOLS_UNABLE_TO_CREATE_UPLOAD_PATH') . $path);
 				$this->displayTask($pid, $version);
@@ -717,7 +717,7 @@ class ToolsControllerScreenshots extends Hubzero_Controller
 	 */
 	public function transfer($sourceid, $destid, $rid)
 	{
-		$xlog = Hubzero_Factory::getLogger();
+		$xlog =& Hubzero_Factory::getLogger();
 		$xlog->logDebug(__FUNCTION__ . '()');
 
 		// Get resource information
@@ -742,7 +742,7 @@ class ToolsControllerScreenshots extends Hubzero_Controller
 		// Make sure the path exist
 		if (!is_dir($src)) 
 		{
-			if (!JFolder::create($src)) 
+			if (!JFolder::create($src, 0777)) 
 			{
 				$this->setError(JText::_('COM_TOOLS_UNABLE_TO_CREATE_UPLOAD_PATH'));
 				return false;
@@ -831,7 +831,7 @@ class ToolsControllerScreenshots extends Hubzero_Controller
 		}
 
 		// get config
-		$this->view->cparams = JComponentHelper::getParams('com_resources');
+		$this->view->cparams =& JComponentHelper::getParams('com_resources');
 		$this->view->version = $version;
 		$this->view->rid = $rid;
 
@@ -864,7 +864,7 @@ class ToolsControllerScreenshots extends Hubzero_Controller
 		}
 
 		// Get the configured upload path
-		$rconfig = JComponentHelper::getParams('com_resources');
+		$rconfig =& JComponentHelper::getParams('com_resources');
 
 		$base_path = $rconfig->get('uploadpath');
 		if ($base_path) 
