@@ -31,14 +31,14 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$pathway = JFactory::getApplication()->getPathway();
+$pathway =& JFactory::getApplication()->getPathway();
 $pathway->addItem(
 	JText::_('All Pages'),
 	'index.php?option=' . $this->option . '&scope=' . $this->page->scope . '&pagename=Special:NewPages'
 );
 
-$jconfig = JFactory::getConfig();
-$juser = JFactory::getUser();
+$jconfig =& JFactory::getConfig();
+$juser =& JFactory::getUser();
 
 $dir = strtoupper(JRequest::getVar('dir', 'ASC'));
 if (!in_array($dir, array('ASC', 'DESC')))
@@ -46,7 +46,7 @@ if (!in_array($dir, array('ASC', 'DESC')))
 	$dir = 'ASC';
 }
 
-$database = JFactory::getDBO();
+$database =& JFactory::getDBO();
 
 $where = '';
 $namespace = urldecode(JRequest::getVar('namespace', ''));
@@ -98,10 +98,18 @@ $rows = $database->loadObjectList();
 		
 		<input type="submit" value="<?php echo JText::_('Go'); ?>" />
 	</fieldset>
-	<div class="grid">
+	
 <?php
 if ($rows) 
 {
+	$dateFormat = '%d %b %Y';
+	$tz = 0;
+	if (version_compare(JVERSION, '1.6', 'ge'))
+	{
+		$dateFormat = 'd M Y';
+		$tz = true;
+	}
+
 	$columns = array_chunk($rows, ceil(count($rows) / 3 ), true /* preserve keys */ );
 
 	$index = '';
@@ -110,12 +118,12 @@ if ($rows)
 	{
 		switch ($i)
 		{
-			case 0: $cls = ''; break;
-			case 1: $cls = ''; break;
-			case 2: $cls = 'omega'; break;
+			case 0: $cls = 'first'; break;
+			case 1: $cls = 'second'; break;
+			case 2: $cls = 'third'; break;
 		}
 ?>
-		<div class="col span-third <?php echo $cls; ?>">
+		<div class="three columns <?php echo $cls; ?>">
 			<?php
 		if (count($column) > 0)
 		{
@@ -158,6 +166,6 @@ if ($rows)
 	}
 }
 ?>
-		</div>
+		<div class="clear"></div>
 	</div>
 </form>
