@@ -55,35 +55,37 @@ class Hubzero_Document
 	 */
 	public static function addComponentStylesheet($component, $stylesheet = '', $type = 'text/css', $media = null, $attribs = array())
 	{
-		$mainframe = JFactory::getApplication();
+		$mainframe =& JFactory::getApplication();
+
+		$jdocument = &JFactory::getDocument();
+
 		$template  = $mainframe->getTemplate();
 
 		if (empty($stylesheet)) 
 		{
 			$stylesheet = substr($component, 4) . '.css';
 		}
-		if (substr(strtolower($stylesheet), -4) != '.css')
+
+		$templatecss = DS . 'templates' . DS . $template . DS . 'html' . DS . $component . DS . $stylesheet;
+
+		$assetcss = DS . 'components' . DS . $component . DS . 'assets' . DS . 'css' . DS . $stylesheet;
+
+		$componentcss = DS . 'components' . DS . $component . DS . $stylesheet;
+
+		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
-			$stylesheet .= '.css';
+			// Chech for CSS in /templates/$template/html/$component/
+			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
 		}
-
-		// Build a list of possible paths
-		$paths = array();
-
-		$paths[] = DS . 'templates' . DS . $template . DS . 'html' . DS . $component . DS . $stylesheet;
-		$paths[] = DS . 'components' . DS . $component . DS . 'assets' . DS . 'css' . DS . $stylesheet;
-		$paths[] = DS . 'components' . DS . $component . DS . $stylesheet;
-
-		// Run through each path until we find one that works
-		foreach ($paths as $path)
+		else if (file_exists(JPATH_SITE . $assetcss)) 
 		{
-			if (file_exists(JPATH_SITE . $path)) 
-			{
-				// Push script to the document
-				$jdocument = JFactory::getDocument();
-				$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $path . '?v=' . filemtime(JPATH_SITE . $path), $type, $media, $attribs);
-				break;
-			}
+			// Chech for CSS in /components/$component/assets/css/
+			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $assetcss . '?v=' . filemtime(JPATH_SITE . $assetcss), $type, $media, $attribs);
+		} 
+		else if (file_exists(JPATH_SITE . $componentcss)) 
+		{
+			// Chech for CSS in /components/$component/
+			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $componentcss . '?v=' . filemtime(JPATH_SITE . $componentcss), $type, $media, $attribs);
 		}
 	}
 
@@ -99,41 +101,36 @@ class Hubzero_Document
 	 */
 	public static function addComponentScript($component, $script = '', $type = "text/javascript", $defer = false, $async = false)
 	{
+		$mainframe = JFactory::getApplication();
+
+		$jdocument = JFactory::getDocument();
+
+		$template  = $mainframe->getTemplate();
+
 		if (empty($script)) 
 		{
 			$script = substr($component, 4);
 		}
 
-		// We need to momentarily strip the file extension
-		if (substr(strtolower($script), -3) == '.js')
-		{
-			$script .= substr($script, 0, -3);
-		}
-
 		$base = DS . 'components' . DS . $component;
 
-		// Build a list of possible paths
-		$paths = array();
-
+		$url = $base . DS . $script . '.js';
+		$urlAlt = '';
 		if (JPluginHelper::isEnabled('system', 'jquery'))
 		{
-			$paths[] = $base . DS . 'assets' . DS . 'js' . DS . $script . '.jquery.js';
-			$paths[] = $base . DS . $script . '.jquery.js';
+			if (file_exists(JPATH_SITE . $base . DS . $script . '.jquery.js')) 
+			{
+				$urlAlt .= $base . DS . $script . '.jquery.js';
+			}
 		}
 
-		$paths[] = $base . DS . 'assets' . DS . 'js' . DS . $script . '.js';
-		$paths[] = $base . DS . $script . '.js';
-
-		// Run through each path until we find one that works
-		foreach ($paths as $path)
+		if ($urlAlt && file_exists(JPATH_SITE . $urlAlt)) 
 		{
-			if (file_exists(JPATH_SITE . $path)) 
-			{
-				// Push script to the document
-				$jdocument = JFactory::getDocument();
-				$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $path . '?v=' . filemtime(JPATH_SITE . $path), $type, $defer, $async);
-				break;
-			}
+			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
+		} 
+		else if (file_exists(JPATH_SITE . $url)) 
+		{
+			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
 		}
 	}
 
@@ -153,9 +150,9 @@ class Hubzero_Document
 			return;
 		}
 
-		$mainframe = JFactory::getApplication();
+		$mainframe =& JFactory::getApplication();
 
-		$jdocument = JFactory::getDocument();
+		$jdocument = &JFactory::getDocument();
 
 		$template  = $mainframe->getTemplate();
 
@@ -227,7 +224,7 @@ class Hubzero_Document
 	 */
 	public static function getComponentImage($component, $image)
 	{
-		$mainframe = JFactory::getApplication();
+		$mainframe =& JFactory::getApplication();
 
 		$template  = $mainframe->getTemplate();
 
@@ -261,7 +258,7 @@ class Hubzero_Document
 	 */
 	public static function getComponentStylesheet($component, $stylesheet)
 	{
-		$mainframe = JFactory::getApplication();
+		$mainframe =& JFactory::getApplication();
 
 		$template  = $mainframe->getTemplate();
 
@@ -295,7 +292,7 @@ class Hubzero_Document
 	 */
 	public static function getModuleImage($module, $image)
 	{
-		$mainframe = JFactory::getApplication();
+		$mainframe =& JFactory::getApplication();
 
 		$template  = $mainframe->getTemplate();
 
@@ -325,34 +322,28 @@ class Hubzero_Document
 	 */
 	public static function addModuleStyleSheet($module, $stylesheet = '', $type = 'text/css', $media = null, $attribs = array())
 	{
-		$mainframe = JFactory::getApplication();
+		$mainframe =& JFactory::getApplication();
+
+		$jdocument = &JFactory::getDocument();
+
 		$template  = $mainframe->getTemplate();
 
 		if (empty($stylesheet)) 
 		{
 			$stylesheet = $module . '.css';
 		}
-		if (substr(strtolower($stylesheet), -4) != '.css')
+
+		$templatecss = DS . 'templates' . DS . $template . DS . 'html' . DS . $module . DS . $stylesheet;
+
+		$modulecss = DS . 'modules' . DS . $module . DS . $stylesheet;
+
+		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
-			$stylesheet .= '.css';
-		}
-
-		// Build a list of possible paths
-		$paths = array();
-
-		$paths[] = DS . 'templates' . DS . $template . DS . 'html' . DS . $module . DS . $stylesheet;
-		$paths[] = DS . 'modules' . DS . $module . DS . $stylesheet;
-
-		// Run through each path until we find one that works
-		foreach ($paths as $path)
+			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
+		} 
+		else 
 		{
-			if (file_exists(JPATH_SITE . $path)) 
-			{
-				// Push script to the document
-				$jdocument = JFactory::getDocument();
-				$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $path . '?v=' . filemtime(JPATH_SITE . $path), $type, $media, $attribs);
-				break;
-			}
+			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $modulecss . '?v=' . filemtime(JPATH_SITE . $modulecss), $type, $media, $attribs);
 		}
 	}
 	
@@ -366,9 +357,12 @@ class Hubzero_Document
 	 * @param   bool    $async		Adds the async attribute.
 	 * @return  void
 	 */
-	public static function addModuleScript($module, $script = '', $type = 'text/javascript', $defer = false, $async = false)
+	public static function addModuleScript($module, $script = '', $type = "text/javascript", $defer = false, $async = false)
 	{
 		$mainframe = JFactory::getApplication();
+
+		$jdocument = JFactory::getDocument();
+
 		$template  = $mainframe->getTemplate();
 
 		if (empty($script)) 
@@ -376,34 +370,20 @@ class Hubzero_Document
 			$script = $module;
 		}
 
-		// We need to momentarily strip the file extension
-		if (substr(strtolower($script), -3) == '.js')
-		{
-			$script .= substr($script, 0, -3);
-		}
-
-		// Build a list of possible paths
-		$paths = array();
-
+		$url = DS . 'modules' . DS . $module . DS . $script . '.js';
+		$urlAlt = '';
 		if (JPluginHelper::isEnabled('system', 'jquery'))
 		{
-			$paths[] = DS . 'templates' . DS . $template . DS . 'html' . DS . $module . DS . $script . '.jquery.js';
-			$paths[] = DS . 'modules' . DS . $module . DS . $script . '.jquery.js';
+			$urlAlt = DS . 'modules' . DS . $module . DS . $script . '.jquery.js';
 		}
 
-		$paths[] = DS . 'templates' . DS . $template . DS . 'html' . DS . $module . DS . $script . '.js';
-		$paths[] = DS . 'modules' . DS . $module . DS . $script . '.js';
-
-		// Run through each path until we find one that works
-		foreach ($paths as $path)
+		if ($urlAlt && file_exists(JPATH_SITE . $urlAlt)) 
 		{
-			if (file_exists(JPATH_SITE . $path)) 
-			{
-				// Push script to the document
-				$jdocument = JFactory::getDocument();
-				$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $path . '?v=' . filemtime(JPATH_SITE . $path), $type, $defer, $async);
-				break;
-			}
+			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
+		} 
+		else 
+		{
+			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
 		}
 	}
 
@@ -420,37 +400,30 @@ class Hubzero_Document
 	 */
 	public static function addPluginStyleSheet($folder, $plugin, $stylesheet = '', $type = 'text/css', $media = null, $attribs = array())
 	{
-		$mainframe = JFactory::getApplication();
+		$mainframe =& JFactory::getApplication();
+
+		$jdocument =& JFactory::getDocument();
+
 		$template  = $mainframe->getTemplate();
 
 		if (empty($stylesheet)) 
 		{
 			$stylesheet = $plugin . '.css';
 		}
-		if (substr(strtolower($stylesheet), -4) != '.css')
+		$templatecss = DS . 'templates' . DS . $template . DS . 'html' . DS . 'plg_' . $folder . '_' . $plugin . DS . $stylesheet;
+
+		$plugincss = DS . 'plugins' . DS . $folder . DS . $plugin . DS . $stylesheet;
+
+		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
-			$stylesheet .= '.css';
-		}
-
-		// Build a list of possible paths
-		$paths = array();
-
-		$paths[] = DS . 'templates' . DS . $template . DS . 'html' . DS . 'plg_' . $folder . '_' . $plugin . DS . $stylesheet;
-		$paths[] = DS . 'plugins' . DS . $folder . DS . $plugin . DS . $stylesheet;
-
-		// Run through each path until we find one that works
-		foreach ($paths as $path)
+			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
+		} 
+		else if (file_exists(JPATH_SITE . $plugincss))
 		{
-			if (file_exists(JPATH_SITE . $path)) 
-			{
-				// Push script to the document
-				$jdocument = JFactory::getDocument();
-				$jdocument->addStyleSheet(str_replace('/administrator', '', rtrim(JURI::getInstance()->base(true), DS)) . $path . '?v=' . filemtime(JPATH_SITE . $path), $type, $media, $attribs);
-				break;
-			}
+			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $plugincss . '?v=' . filemtime(JPATH_SITE . $plugincss), $type, $media, $attribs);
 		}
 	}
-
+	
 	/**
 	 * Adds a linked script to the page
 	 *
@@ -462,9 +435,12 @@ class Hubzero_Document
 	 * @param   bool    $async		Adds the async attribute.
 	 * @return  void
 	 */
-	public static function addPluginScript($folder, $plugin, $script = '', $type = 'text/javascript', $defer = false, $async = false)
+	public static function addPluginScript($folder, $plugin, $script = '', $type = "text/javascript", $defer = false, $async = false)
 	{
 		$mainframe = JFactory::getApplication();
+
+		$jdocument = JFactory::getDocument();
+
 		$template  = $mainframe->getTemplate();
 
 		if (empty($script)) 
@@ -472,34 +448,20 @@ class Hubzero_Document
 			$script = $plugin;
 		}
 
-		// We need to momentarily strip the file extension
-		if (substr(strtolower($script), -3) == '.js')
-		{
-			$script .= substr($script, 0, -3);
-		}
-
-		// Build a list of possible paths
-		$paths = array();
-
+		$url = DS . 'plugins' . DS . $folder . DS . $plugin . DS . $script . '.js';
+		$urlAlt = '';
 		if (JPluginHelper::isEnabled('system', 'jquery'))
 		{
-			$paths[] = DS . 'templates' . DS . $template . DS . 'html' . DS . 'plg_' . $folder . '_' . $plugin . DS . $script . '.jquery.js';
-			$paths[] = DS . 'plugins' . DS . $folder . DS . $plugin . DS . $script . '.jquery.js';
+			$urlAlt = DS . 'plugins' . DS . $folder . DS . $plugin . DS . $script . '.jquery.js';
 		}
 
-		$paths[] = DS . 'templates' . DS . $template . DS . 'html' . DS . 'plg_' . $folder . '_' . $plugin . DS . $script . '.js';
-		$paths[] = DS . 'plugins' . DS . $folder . DS . $plugin . DS . $script . '.js';
-
-		// Run through each path until we find one that works
-		foreach ($paths as $path)
+		if ($urlAlt && file_exists(JPATH_SITE . $urlAlt)) 
 		{
-			if (file_exists(JPATH_SITE . $path)) 
-			{
-				// Push script to the document
-				$jdocument = JFactory::getDocument();
-				$jdocument->addScript(str_replace('/administrator', '', rtrim(JURI::getInstance()->base(true), DS)) . $path . '?v=' . filemtime(JPATH_SITE . $path), $type, $defer, $async);
-				break;
-			}
+			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
+		} 
+		else if (file_exists(JPATH_SITE . $url)) 
+		{
+			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
 		}
 	}
 
@@ -518,8 +480,6 @@ class Hubzero_Document
 		// Path to system CSS
 		$thispath = JPATH_ROOT . DS . 'media' . DS . 'system' . DS . 'css';
 
-		$env = JFactory::getConfig()->getValue('config.application_env', 'production');
-
 		try {
 			// Primary build file
 			$primary   = 'site';
@@ -529,7 +489,7 @@ class Hubzero_Document
 
 			// If debugging is turned off and a cache file exist
 			//if (!JDEBUG && file_exists($output))
-			if ($env == 'production' && file_exists($output))
+			if (JFactory::getConfig()->getValue('config.application_env', 'production') == 'production' && file_exists($output))
 			{
 				$output =  DS . 'cache' . DS . $primary. '.css?v=' . filemtime($output);
 			}
@@ -537,17 +497,9 @@ class Hubzero_Document
 			{
 				$lesspath = JPATH_ROOT . DS . 'media' . DS . 'system' . DS . 'less';
 
-				if (!class_exists('lessc'))
-				{
-					throw new Exception('LESS parser not found.');
-				}
-
 				// Try to compile LESS files
 				$less = new lessc;
-				if ($env != 'development')
-				{
-					$less->setFormatter('compressed');
-				}
+				$less->setFormatter('compressed');
 
 				// Are there any template overrides?
 				$template  = JPATH_ROOT . DS . 'templates' . DS . JFactory::getApplication()->getTemplate() . DS . 'less'; // . 'bootstrap.less';
@@ -573,32 +525,6 @@ class Hubzero_Document
 					$cache = unserialize(file_get_contents($cacheFile));
 				}
 
-				if ($cache && is_array($cache['files']))
-				{
-					foreach ($cache['files'] as $fname => $ftime) 
-					{
-						$path = explode('/', $fname);
-						$file = array_pop($path);
-
-						if (file_exists($template . '/' . $file))
-						{
-							$nname = $template . '/' . $file;
-						}
-						else
-						{
-							$nname = $lesspath . '/' . $file;
-						}
-
-						if ($fname != $nname or !file_exists($nname) or filemtime($nname) > $ftime) 
-						{
-							// One of the files we knew about previously has changed
-							// so we should look at our incoming root again.
-							$cache = $input;
-							break;
-						}
-					}
-				}
-
 				// If no cache file or the root build file is different
 				if (!$cache || ($cache['root'] != $input))
 				{
@@ -615,23 +541,15 @@ class Hubzero_Document
 				)
 				*/
 
-				if (is_string($cache)) 
-				{
-					$newCache = $less->cachedCompile($cache);
-				}
-				else
-				{
-					$newCache = $cache;
-				}
+				$newCache = $less->cachedCompile($cache);
 
 				// Did the cache change?
 				if (!is_array($cache) || $newCache['updated'] > $cache['updated']) 
 				{
 					file_put_contents($cacheFile, serialize($newCache));  // Update the compiled LESS timestamp
-					$newCache['compiled'] = str_replace("'/media/system/", "'" . rtrim(JURI::getInstance()->base(true), DS) . '/media/system/', $newCache['compiled']);
 					file_put_contents($output, $newCache['compiled']);    // Update the compiled LESS
 				}
-				$output =  rtrim(JURI::root(true), '/') . DS . 'cache' . DS . $primary . '.css?v=' . $newCache['updated'];
+				$output =  DS . 'cache' . DS . $primary . '.css?v=' . $newCache['updated'];
 			}
 		} 
 		catch (exception $e) 
