@@ -11,8 +11,7 @@ class Hubzero_Ldap
 		'success'  => true,
 		'added'    => 0,
 		'deleted'  => 0,
-		'modified' => 0,
-		'unchanged' => 0
+		'modified' => 0
 		);
 
 	public static function getLDO($debug = 0)
@@ -55,7 +54,7 @@ class Hubzero_Ldap
 			}
 		}
 
-		$conn = ldap_connect($pldap, $port);
+		$conn = @ldap_connect($pldap, $port);
 
 		if ($conn === false)
 		{
@@ -72,7 +71,7 @@ class Hubzero_Ldap
 			Hubzero_Factory::getLogger()->logDebug("getLDO(): ldap_connect($pldap,$port) success. ");
 		}
 
-		if (ldap_set_option($conn, LDAP_OPT_PROTOCOL_VERSION, 3) == false)
+		if (@ldap_set_option($conn, LDAP_OPT_PROTOCOL_VERSION, 3) == false)
 		{
 			if ($debug)
 			{
@@ -88,7 +87,7 @@ class Hubzero_Ldap
 			Hubzero_Factory::getLogger()->logDebug("getLDO(): ldap_set_option(LDAP_OPT_PROTOCOL_VERSION, 3) success.");
 		}
 
-		if (ldap_set_option($conn, LDAP_OPT_RESTART, 1) == false)
+		if (@ldap_set_option($conn, LDAP_OPT_RESTART, 1) == false)
 		{
 			if ($debug)
 			{
@@ -104,7 +103,7 @@ class Hubzero_Ldap
 			Hubzero_Factory::getLogger()->logDebug("getLDO(): ldap_set_option(LDAP_OPT_RESTART, 1) success.");
 		}
 
-		if (!ldap_set_option($conn, LDAP_OPT_REFERRALS, false))
+		if (!@ldap_set_option($conn, LDAP_OPT_REFERRALS, false))
 		{
 			if ($debug)
 			{
@@ -122,7 +121,7 @@ class Hubzero_Ldap
 
 		if ($negotiate_tls)
 		{
-			if (!ldap_start_tls($conn))
+			if (!@ldap_start_tls($conn))
 			{
 				if ($debug)
 				{
@@ -139,7 +138,7 @@ class Hubzero_Ldap
 			}
 		}
 
-		if (ldap_bind($conn, $acctman, $acctmanPW) == false)
+		if (@ldap_bind($conn, $acctman, $acctmanPW) == false)
 		{
 			$err     = ldap_errno($conn);
 			$errstr  = ldap_error($conn);
@@ -180,7 +179,7 @@ class Hubzero_Ldap
 			return false;
 		}
 
-		$query = "SELECT p.uidNumber AS uidNumber, u.username AS uid, p.name AS cn, " .
+		$query = "SELECT u.id AS uidNumber, u.username AS uid, u.name AS cn, " .
 				" p.gidNumber, p.homeDirectory, p.loginShell, " .
 				" pwd.passhash AS userPassword, pwd.shadowLastChange, pwd.shadowMin, pwd.shadowMax, pwd.shadowWarning, " .
 				" pwd.shadowInactive, pwd.shadowExpire, pwd.shadowFlag " .
@@ -230,9 +229,9 @@ class Hubzero_Ldap
 		$reqattr = array('uidNumber','uid','cn','gidNumber','homeDirectory','loginShell','userPassword','shadowLastChange',
 				'shadowMin','shadowMax','shadowWarning','shadowInactive','shadowExpire','shadowFlag', 'host');
 	
-		$entry = ldap_search($conn, $dn, $filter, $reqattr, 0, 1, 0);
+		$entry = @ldap_search($conn, $dn, $filter, $reqattr, 0, 1, 0);
 		
-		$count = ($entry) ? ldap_count_entries($conn, $entry) : 0;
+		$count = ($entry) ? @ldap_count_entries($conn, $entry) : 0;
 			
 		/* If there was a database entry, but there was no ldap entry, create the ldap entry */
 	
@@ -270,11 +269,11 @@ class Hubzero_Ldap
 				return false;
 			}
 			
-			$result = ldap_add($conn, $dn, $entry);
+			$result = @ldap_add($conn, $dn, $entry);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 				return false;
 			}
 			else
@@ -288,9 +287,9 @@ class Hubzero_Ldap
 			
 		if ($count > 0)
 		{
-			$firstentry = ldap_first_entry($conn, $entry);
+			$firstentry = @ldap_first_entry($conn, $entry);
 	
-			$attr = ldap_get_attributes($conn, $firstentry);
+			$attr = @ldap_get_attributes($conn, $firstentry);
 
 			if (!empty($attr))
 			{
@@ -300,7 +299,7 @@ class Hubzero_Ldap
 						
 					if (isset($attr[$key][0]))
 					{
-						if (count($attr[$key]) <= 1)
+						if (count($attr[$key]) <= 2)
 						{
 							$ldapinfo[$key] = $attr[$key][0];
 						}
@@ -330,11 +329,11 @@ class Hubzero_Ldap
 		{
 			$dn = "uid=" . $ldapinfo['uid'] . ",ou=users," . $hubLDAPBaseDN;
 	
-			$result = ldap_delete($conn, $dn);
+			$result = @ldap_delete($conn, $dn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 				return false;
 			}
 			else
@@ -346,11 +345,6 @@ class Hubzero_Ldap
 	
 		/* Otherwise update the ldap entry */
 	
-		if (!empty($ldapinfo['host']) && !is_array($ldapinfo['host']))
-		{
-			$ldapinfo['host'] = array($ldapinfo['host']);
-		}
-
 		$entry = array();
 	
 		foreach ($dbinfo as $key=>$value)
@@ -367,19 +361,14 @@ class Hubzero_Ldap
 				}
 			}
 		}
-
-		if (empty($entry))
-		{
-			++self::$success['unchanged'];
-			return true;
-		}
-
+	
 		$dn = "uid=" . $ldapinfo['uid'] . ",ou=users," . $hubLDAPBaseDN;
-		$result = ldap_modify($conn, $dn, $entry);
+		
+		$result = @ldap_modify($conn, $dn, $entry);
 
 		if($result !== true)
 		{
-			self::$errors['warning'][] = ldap_error($conn);
+			self::$errors['warning'][] = @ldap_error($conn);
 			return false;
 		}
 		else
@@ -389,7 +378,7 @@ class Hubzero_Ldap
 		}
 	}
 	
-	public static function syncGroup($group)
+	static function syncGroup($group)
 	{
 		$db = JFactory::getDBO();
 	
@@ -431,12 +420,22 @@ class Hubzero_Ldap
 		$ldap_params = JComponentHelper::getParams('com_system');
 		$hubLDAPBaseDN = $ldap_params->get('ldap_basedn','');
 
-		$dn = "cn=" . $dbinfo['cn'] . ",ou=groups," . $hubLDAPBaseDN;
-		$filter = '(objectclass=*)';
+		if (is_numeric($group) && $group >= 0)
+		{
+			$dn = 'ou=groups,' . $hubLDAPBaseDN;
+			$filter = '(gidNumber=' . $group . ')';
+		}
+		else
+		{
+			$dn = "cn=$group,ou=groups," . $hubLDAPBaseDN;
+			$filter = '(objectclass=*)';
+		}
+
 		$reqattr = array('gidNumber','cn','description','memberUid');
 
-		$entry = ldap_search($conn, $dn, $filter, $reqattr, 0, 1, 0);
-		$count = ($entry) ? ldap_count_entries($conn, $entry) : 0;
+		$entry = @ldap_search($conn, $dn, $filter, $reqattr, 0, 1, 0);
+		
+		$count = ($entry) ? @ldap_count_entries($conn, $entry) : 0;
 
 		/* If there was a database entry, but there was no ldap entry, create the ldap entry */
 
@@ -460,12 +459,11 @@ class Hubzero_Ldap
 				}
 			}
 
-			$result = ldap_add($conn, $dn, $entry);
+			$result = @ldap_add($conn, $dn, $entry);
 
 			if($result !== true)
 			{
-				$result = ldap_add($conn, $dn, $entry);
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 				return false;
 			}
 			else
@@ -477,13 +475,13 @@ class Hubzero_Ldap
 
 		$ldapinfo = null;
 			
-		$count = ($entry) ? ldap_count_entries($conn, $entry) : 0;
+		$count = ($entry) ? @ldap_count_entries($conn, $entry) : 0;
 
 		if ($count > 0)
 		{
-			$firstentry = ldap_first_entry($conn, $entry);
+			$firstentry = @ldap_first_entry($conn, $entry);
 
-			$attr = ldap_get_attributes($conn, $firstentry);
+			$attr = @ldap_get_attributes($conn, $firstentry);
 
 			if (!empty($attr) && $attr['count'] > 0)
 			{
@@ -493,7 +491,7 @@ class Hubzero_Ldap
 
 					if (isset($attr[$key][0]))
 					{
-						if (count($attr[$key]) <= 1)
+						if (count($attr[$key]) <= 2)
 						{
 							$ldapinfo[$key] = $attr[$key][0];
 						}
@@ -523,11 +521,11 @@ class Hubzero_Ldap
 		{
 			$dn = "cn=" . $ldapinfo['cn'] . ",ou=groups," . $hubLDAPBaseDN;
 
-			$result = ldap_delete($conn, $dn);
+			$result = @ldap_delete($conn, $dn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 				return false;
 			}
 			else
@@ -541,11 +539,6 @@ class Hubzero_Ldap
 
 		$entry = array();
 
-		if (!empty($ldapinfo['memberUid']) && !is_array($ldapinfo['memberUid']))
-		{
-			$ldapinfo['memberUid'] = array($ldapinfo['memberUid']);
-		}
-
 		foreach ($dbinfo as $key=>$value)
 		{
 			if ($ldapinfo[$key] != $dbinfo[$key])
@@ -561,18 +554,11 @@ class Hubzero_Ldap
 			}
 		}
 
-		$dn = "cn=" . $dbinfo['cn'] . ",ou=groups," . $hubLDAPBaseDN;
-		if (empty($entry))
-		{
-			++self::$success['unchanged'];
-			return true;
-		}
-
-		$result = ldap_modify($conn, $dn, $entry);
+		$result = @ldap_modify($conn, $dn, $entry);
 
 		if($result !== true)
 		{
-			self::$errors['warning'][] = ldap_error($conn);
+			self::$errors['warning'][] = @ldap_error($conn);
 			return false;
 		}
 		else
@@ -582,17 +568,17 @@ class Hubzero_Ldap
 		}
 	}
 	
-	public static function addGroupMemberships($group, $members)
+	static function addGroupMemberships($group, $members)
 	{
 		self::changeGroupMemberships($group, $members, array());
 	}
 	
-	public static function removeGroupMemberships($group, $members)
+	static function removeGroupMemberships($group, $members)
 	{
 		self::changeGroupMemberships($group, array(), $members);
 	}
 	
-	public static function changeGroupMemberships($group,$add,$delete)
+	static function changeGroupMemberships($group,$add,$delete)
 	{
 		$db = JFactory::getDBO();
 		
@@ -624,9 +610,9 @@ class Hubzero_Ldap
 	
 		$reqattr = array('gidNumber','cn');
 	
-		$entry = ldap_search($conn, $dn, $filter, $reqattr, 0, 1, 0);
+		$entry = @ldap_search($conn, $dn, $filter, $reqattr, 0, 1, 0);
 		
-		$count = ldap_count_entries($conn, $entry);
+		$count = @ldap_count_entries($conn, $entry);
 		
 		/* If there was a database entry, but there was no ldap entry, create the ldap entry */
 	
@@ -639,9 +625,9 @@ class Hubzero_Ldap
 			
 		if ($count > 0)
 		{
-			$firstentry = ldap_first_entry($conn, $entry);
+			$firstentry = @ldap_first_entry($conn, $entry);
 	
-			$attr = ldap_get_attributes($conn, $firstentry);
+			$attr = @ldap_get_attributes($conn, $firstentry);
 	
 			if (!empty($attr) && $attr['count'] > 0)
 			{
@@ -692,12 +678,12 @@ class Hubzero_Ldap
 				$adds['memberUid'][] = $memberUid;
 			}
 			
-			if (ldap_mod_add($conn, $dn, $adds) == false)
+			if (@ldap_mod_add($conn, $dn, $adds) == false)
 			{
 				// if bulk add fails, try individual
 				foreach($add as $memberUid)
 				{
-					ldap_mod_add($conn, $dn, array('memberUid' => $memberUid));
+					@ldap_mod_add($conn, $dn, array('memberUid' => $memberUid));
 				}
 			}
 		}
@@ -721,7 +707,7 @@ class Hubzero_Ldap
 				$deletes['memberUid'][] = $memberUid;
 			}
 	
-			ldap_mod_del($conn, $dn, $deletes);
+			@ldap_mod_del($conn, $dn, $deletes);
 		}
 	}
 	
@@ -732,7 +718,7 @@ class Hubzero_Ldap
 	 *
 	 * @return     boolean Return description (if any) ...
 	 */
-	public static function syncAllGroups()
+	public function syncAllGroups()
 	{
 		// @TODO: chunk this to 1000 groups at a time
 		
@@ -777,7 +763,7 @@ class Hubzero_Ldap
 	 *
 	 * @return     boolean Return description (if any) ...
 	 */
-	public static function syncAllUsers()
+	public function syncAllUsers()
 	{
 		// @TODO: chunk this to 1000 users at a time
 		
@@ -833,19 +819,19 @@ class Hubzero_Ldap
     	$dn = "ou=groups," . $hubLDAPBaseDN;
 	    $filter = '(objectclass=hubGroup)';
 
-        $sr = ldap_search($conn, $dn, $filter, array('gid','cn'), 0, 0, 0);
+        $sr = @ldap_search($conn, $dn, $filter, array('gid','cn'), 0, 0, 0);
 
         $gids = array();
         
         if ($sr !== false) 
         {
-	        if (ldap_count_entries($conn, $sr) !== false) 
+	        if (@ldap_count_entries($conn, $sr) !== false) 
         	{
-		        $entry = ldap_first_entry($conn, $sr);
+		        $entry = @ldap_first_entry($conn, $sr);
 
         		while ($entry !== false) 
         		{
-        			$attr = ldap_get_attributes($conn, $entry);
+        			$attr = @ldap_get_attributes($conn, $entry);
         			
 					if (array_key_exists('gid', $attr))
 					{
@@ -856,18 +842,18 @@ class Hubzero_Ldap
 						$gids[] = "cn=" . $attr['cn'][0] . "," .  "ou=groups," . $hubLDAPBaseDN;
 					}
 
-        			$entry = ldap_next_entry($conn, $entry);
+        			$entry = @ldap_next_entry($conn, $entry);
             	}
         	}
         }
         
         foreach($gids as $giddn)
         {
-			$result = ldap_delete($conn, $giddn);
+			$result = @ldap_delete($conn, $giddn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 			}
 			else
 			{
@@ -895,11 +881,11 @@ class Hubzero_Ldap
         foreach($result as $row)
         {
         	$dn = "cn=$row," .  "ou=groups," . $hubLDAPBaseDN;
-			$result = ldap_delete($conn, $dn);
+			$result = @ldap_delete($conn, $dn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 			}
 			else
 			{
@@ -912,23 +898,23 @@ class Hubzero_Ldap
 	    $dn = "ou=groups," . $hubLDAPBaseDN;
 	    $filter = '(&(objectclass=posixGroup)(gidNumber>=1000))';
 
-        $sr = ldap_search($conn, $dn, $filter, array('gid'), 0, 0, 0);
+        $sr = @ldap_search($conn, $dn, $filter, array('gid'), 0, 0, 0);
         
         $gids = array();
         
         if ($sr !== false) 
         {
-	        if (ldap_count_entries($conn, $sr) !== false) 
+	        if (@ldap_count_entries($conn, $sr) !== false) 
         	{
-		        $entry = ldap_first_entry($conn, $sr);
+		        $entry = @ldap_first_entry($conn, $sr);
 
         		while ($entry !== false) 
         		{
-        			$attr = ldap_get_attributes($conn, $firstentry);
+        			$attr = @ldap_get_attributes($conn, $firstentry);
         			
         			$gids[] = $attr['gid'][0];
         			
-        			$entry = ldap_next_entry($conn, $entry);
+        			$entry = @ldap_next_entry($conn, $entry);
         		}
         	}
         }
@@ -936,11 +922,11 @@ class Hubzero_Ldap
         foreach($gids as $gid)
         {
         	$dn = "gid=$gid," . "ou=groups," . $hubLDAPBaseDN;
-			$result = ldap_delete($conn, $dn);
+			$result = @ldap_delete($conn, $dn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 			}
 			else
 			{
@@ -976,23 +962,23 @@ class Hubzero_Ldap
     	$dn = "ou=users," . $hubLDAPBaseDN;
 	    $filter = '(objectclass=hubAccount)';
 
-        $sr = ldap_search($conn, $dn, $filter, array('uid'), 0, 0, 0);
+        $sr = @ldap_search($conn, $dn, $filter, array('uid'), 0, 0, 0);
 
         $uids = array();
         
         if ($sr !== false) 
         {
-	        if (ldap_count_entries($conn, $sr) !== false) 
+	        if (@ldap_count_entries($conn, $sr) !== false) 
         	{
-		        $entry = ldap_first_entry($conn, $sr);
+		        $entry = @ldap_first_entry($conn, $sr);
 
         		while ($entry !== false) 
         		{
-        			$attr = ldap_get_attributes($conn, $entry);
+        			$attr = @ldap_get_attributes($conn, $entry);
         			
         			$uids[] = $attr['uid'][0];
         			
-        			$entry = ldap_next_entry($conn, $entry);
+        			$entry = @ldap_next_entry($conn, $entry);
         		}
         	}
         }
@@ -1000,11 +986,11 @@ class Hubzero_Ldap
         foreach($uids as $uid)
         {
         	$dn = "uid=$uid," . "ou=users," . $hubLDAPBaseDN;
-			$result = ldap_delete($conn, $dn);
+			$result = @ldap_delete($conn, $dn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 			}
 			else
 			{
@@ -1032,11 +1018,11 @@ class Hubzero_Ldap
         foreach($result as $row)
         {
         	$dn = "uid=$row," .  "ou=users," . $hubLDAPBaseDN;
-			$result = ldap_delete($conn, $dn);
+			$result = @ldap_delete($conn, $dn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 			}
 			else
 			{
@@ -1049,23 +1035,23 @@ class Hubzero_Ldap
 	    $dn = "ou=users," . $hubLDAPBaseDN;
 	    $filter = '(&(objectclass=posixAccoiunt)(uidNumber>=1000))';
 
-        $sr = ldap_search($conn, $dn, $filter, array('uid'), 0, 0, 0);
+        $sr = @ldap_search($conn, $dn, $filter, array('uid'), 0, 0, 0);
         
         $uids = array();
         
         if ($sr !== false) 
         {
-	        if (ldap_count_entries($conn, $sr) !== false) 
+	        if (@ldap_count_entries($conn, $sr) !== false) 
         	{
 		        $entry = ldap_first_entry($conn, $sr);
 
         		while ($entry !== false) 
         		{
-        			$attr = ldap_get_attributes($conn, $firstentry);
+        			$attr = @ldap_get_attributes($conn, $firstentry);
         			
         			$uids[] = $attr['uid'][0];
         			
-        			$entry = ldap_next_entry($conn, $entry);
+        			$entry = @ldap_next_entry($conn, $entry);
             	}
         	}
         }
@@ -1073,11 +1059,11 @@ class Hubzero_Ldap
         foreach($uids as $uid)
         {
         	$dn = "uid=$uid," . "ou=users," . $hubLDAPBaseDN;
-			$result = ldap_delete($conn, $dn);
+			$result = @ldap_delete($conn, $dn);
 
 			if($result !== true)
 			{
-				self::$errors['warning'][] = ldap_error($conn);
+				self::$errors['warning'][] = @ldap_error($conn);
 			}
 			else
 			{
@@ -1094,4 +1080,4 @@ class Hubzero_Ldap
 			return self::$success;
 		}
 	}
-}
+}
\ No newline at end of file
