@@ -25,21 +25,18 @@ class Migration20130702181838ComWiki extends Hubzero_Migration
 
 		require_once JPATH_ROOT . DS . 'components' . DS . 'com_wiki' . DS . 'tables' . DS . 'revision.php';
 
-		if ($result)
+		$version = new WikiPageRevision($db);
+		$version->loadByVersion($result->pageid, $result->version);
+
+		$hostname = php_uname('n');
+
+		// No need to run this on nanoHUB
+		if (stripos($hostname, 'nanohub') === false)
 		{
-			$version = new WikiPageRevision($db);
-			$version->loadByVersion($result->pageid, $result->version);
+			$pagetext = preg_replace('/(nanoHUB)/', 'This site', $result->pagetext);
+			$pagehtml = preg_replace('/(nanoHUB)/', 'This site', $result->pagehtml);
 
-			$hostname = php_uname('n');
-
-			// No need to run this on nanoHUB
-			if (stripos($hostname, 'nanohub') === false)
-			{
-				$pagetext = preg_replace('/(nanoHUB)/', 'This site', $result->pagetext);
-				$pagehtml = preg_replace('/(nanoHUB)/', 'This site', $result->pagehtml);
-
-				$version->save(array('pagetext'=>$pagetext, 'pagehtml'=>$pagehtml));
-			}
+			$version->save(array('pagetext'=>$pagetext, 'pagehtml'=>$pagehtml));
 		}
 	}
 }
\ No newline at end of file
