@@ -39,7 +39,7 @@ if ($this->collection_id)
 }
 
 ximport('Hubzero_Wiki_Editor');
-$editor = Hubzero_Wiki_Editor::getInstance();
+$editor =& Hubzero_Wiki_Editor::getInstance();
 ?>
 
 <?php if ($this->getError()) { ?>
@@ -50,7 +50,7 @@ $editor = Hubzero_Wiki_Editor::getInstance();
 		<legend><?php echo JText::_('Collect'); ?></legend>
 
 		<div class="grid">
-		<div class="col span-half">
+		<div class="two columns first">
 		<label for="field-collection_id">
 			<?php echo JText::_('Select collection'); ?>
 			<select name="collection_id" id="field-collection_id">
@@ -100,12 +100,13 @@ if ($this->groupboards)
 		</label>
 		</div>
 		<p class="or">OR</p>
-		<div class="col span-half omega">
+		<div class="two columns second">
 			<label for="field-collection_title">
 				<?php echo JText::_('Create collection'); ?>
-				<input type="text" name="collection_title" id="field-collection_title" value="" />
+				<input type="text" name="collection_title" id="field-collection_title" />
 			</label>
 		</div>
+		<div class="clear"></div>
 		</div>
 
 		<label for="field_description">
@@ -152,11 +153,10 @@ if ($this->groupboards)
 	<input type="hidden" name="item_id" value="<?php echo $this->item_id; ?>" />
 	<input type="hidden" name="no_html" value="<?php echo $this->no_html; ?>" />
 
+	<input type="hidden" name="gid" value="<?php echo $this->group->get('cn'); ?>" />
 	<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
-	<input type="hidden" name="cn" value="<?php echo $this->escape($this->group->get('cn')); ?>" />
-	<input type="hidden" name="task" value="view" />
-	<input type="hidden" name="active" value="<?php echo $this->escape($this->name); ?>" />
-	<input type="hidden" name="action" value="collect" />
+	<input type="hidden" name="active" value="<?php echo $this->name; ?>" />
+	<input type="hidden" name="task" value="collect" />
 
 	<p class="submit">
 		<input type="submit" value="<?php echo JText::_('PLG_GROUPS_' . strtoupper($this->name) . '_POST'); ?>" />
