@@ -31,6 +31,16 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+$this->dateFormat  = '%d %b, %Y';
+$this->timeFormat  = '%I:%M %p';
+$this->tz = 0;
+if (version_compare(JVERSION, '1.6', 'ge'))
+{
+	$this->dateFormat  = 'd M, Y';
+	$this->timeFormat  = 'h:i a';
+	$this->tz = true;
+}
+
 ximport('Hubzero_User_Profile_Helper');
 
 $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=' . $this->name;
@@ -58,29 +68,29 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 		<ul>
 <?php if ($this->params->get('access-manage-collection')) { ?>
 			<li>
-				<a class="livefeed tooltips" href="<?php echo JRoute::_($base); ?>" title="<?php echo JText::_('PLG_MEMBERS_COLLECTIONS_FEED_TITLE'); ?>">
-					<span><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_FEED'); ?></span>
+				<a class="livefeed tooltips" href="<?php echo JRoute::_($base); ?>" title="<?php echo JText::_('Live feed :: View posts from everything you\'re following'); ?>">
+					<span><?php echo JText::_('Feed'); ?></span>
 				</a>
 			</li>
 <?php } ?>
 			<li>
 				<a class="collections count active" href="<?php echo JRoute::_($base . '&task=all'); ?>">
-					<span><?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_HEADER_NUM_COLLECTIONS', $this->rows->total()); ?></span>
+					<span><?php echo JText::sprintf('<strong>%s</strong> collections', $this->rows->total()); ?></span>
 				</a>
 			</li>
 			<li>
 				<a class="posts count" href="<?php echo JRoute::_($base . '&task=posts'); ?>">
-					<span><?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_HEADER_NUM_POSTS', $this->posts); ?></span>
+					<span><?php echo JText::sprintf('<strong>%s</strong> posts', $this->posts); ?></span>
 				</a>
 			</li>
 			<li>
 				<a class="followers count" href="<?php echo JRoute::_($base . '&task=followers'); ?>">
-					<span><?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_HEADER_NUM_FOLLOWERS', $this->followers); ?></span>
+					<span><?php echo JText::sprintf('<strong>%s</strong> followers', $this->followers); ?></span>
 				</a>
 			</li>
 			<li>
 				<a class="following count" href="<?php echo JRoute::_($base . '&task=following'); ?>">
-					<span><?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_HEADER_NUM_FOLLOWNG', $this->following); ?></span>
+					<span><?php echo JText::sprintf('<strong>%s</strong> following', $this->following); ?></span>
 				</a>
 			</li>
 		</ul>
@@ -88,10 +98,22 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 		<?php if ($this->params->get('access-create-collection')) { ?>
 		<p>
 			<a class="icon-add add btn" href="<?php echo JRoute::_($base . '&task=new'); ?>">
-				<span><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_NEW_COLLECTION'); ?></span>
+				<span><?php echo JText::_('New collection'); ?></span>
 			</a>
 		</p>
-		<?php } ?>
+		<?php } /*else { ?>
+		<p>
+			<?php if ($this->model->isFollowing()) { ?>
+				<a class="unfollow btn tooltips" data-text-follow="<?php echo JText::_('Follow All'); ?>" data-text-unfollow="<?php echo JText::_('Unfollow All'); ?>" title="<?php echo JText::_('Unfollow All :: Stop following everything this user posts'); ?>" href="<?php echo JRoute::_($base . '&task=unfollow'); ?>">
+					<span><?php echo JText::_('Unfollow All'); ?></span>
+				</a>
+			<?php } else { ?>
+				<a class="follow btn tooltips" data-text-follow="<?php echo JText::_('Follow All'); ?>" data-text-unfollow="<?php echo JText::_('Unfollow All'); ?>" title="<?php echo JText::_('Follow All :: Follow everything this user posts'); ?>" href="<?php echo JRoute::_($base . '&task=follow'); ?>">
+					<span><?php echo JText::_('Follow All'); ?></span>
+				</a>
+			<?php } ?>
+		</p>
+		<?php }*/ ?>
 	<?php } ?>
 		<div class="clear"></div>
 	</fieldset>
@@ -113,7 +135,7 @@ if ($this->rows->total() > 0)
 		'domain'   => 'collection'
 	);
 
-	$p = Hubzero_Wiki_Parser::getInstance();
+	$p =& Hubzero_Wiki_Parser::getInstance();
 
 	foreach ($this->rows as $row)
 	{
@@ -138,10 +160,10 @@ if ($this->rows->total() > 0)
 				<div class="meta">
 					<p class="stats">
 						<span class="likes">
-							<?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_NUM_LIKES', $row->get('positive', 0)); ?>
+							<?php echo JText::sprintf('%s likes', $row->get('positive', 0)); ?>
 						</span>
 						<span class="reposts">
-							<?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_NUM_POSTS', $row->get('posts', 0)); ?>
+							<?php echo JText::sprintf('%s posts', $row->get('posts', 0)); ?>
 						</span>
 					</p>
 				<?php if (!$this->juser->get('guest')) { ?>
@@ -149,25 +171,25 @@ if ($this->rows->total() > 0)
 					<?php if ($row->get('object_type') == 'member' && $row->get('object_id') == $this->juser->get('id')) { ?>
 						<?php if ($this->params->get('access-edit-collection')) { ?>
 							<a class="edit" data-id="<?php echo $row->get('id'); ?>" href="<?php echo JRoute::_($base . '&task=' . $row->get('alias') . '/edit'); ?>">
-								<span><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_EDIT'); ?></span>
+								<span><?php echo JText::_('Edit'); ?></span>
 							</a>
 						<?php } ?>
 						<?php if ($this->params->get('access-delete-collection')) { //!$row->get('is_default') && ?>
 							<a class="delete" data-id="<?php echo $row->get('id'); ?>" href="<?php echo JRoute::_($base . '&task=' . $row->get('alias') . '/delete'); ?>">
-								<span><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_DELETE'); ?></span>
+								<span><?php echo JText::_('Delete'); ?></span>
 							</a>
 						<?php } ?>
 					<?php } else { ?>
 							<a class="repost" data-id="<?php echo $row->get('id'); ?>" href="<?php echo JRoute::_($base . '&task=' . $row->get('alias') . '/collect'); ?>">
-								<span><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_COLLECT'); ?></span>
+								<span><?php echo JText::_('Collect'); ?></span>
 							</a>
 						<?php if ($row->isFollowing()) { ?>
-							<a class="unfollow" data-id="<?php echo $row->get('id'); ?>" data-text-follow="<?php echo JText::_('PLG_MEMBERS_COLLECTIONS_FOLLOW'); ?>" data-text-unfollow="<?php echo JText::_('PLG_MEMBERS_COLLECTIONS_UNFOLLOW'); ?>" href="<?php echo JRoute::_($base . '&task=' . $row->get('alias') . '/unfollow'); ?>">
-								<span><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_UNFOLLOW'); ?></span>
+							<a class="unfollow" data-id="<?php echo $row->get('id'); ?>" data-text-follow="<?php echo JText::_('Follow'); ?>" data-text-unfollow="<?php echo JText::_('Unfollow'); ?>" href="<?php echo JRoute::_($base . '&task=' . $row->get('alias') . '/unfollow'); ?>">
+								<span><?php echo JText::_('Unfollow'); ?></span>
 							</a>
 						<?php } else { ?>
-							<a class="follow" data-id="<?php echo $row->get('id'); ?>" data-text-follow="<?php echo JText::_('PLG_MEMBERS_COLLECTIONS_FOLLOW'); ?>" data-text-unfollow="<?php echo JText::_('PLG_MEMBERS_COLLECTIONS_UNFOLLOW'); ?>" href="<?php echo JRoute::_($base . '&task=' . $row->get('alias') . '/follow'); ?>">
-								<span><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_FOLLOW'); ?></span>
+							<a class="follow" data-id="<?php echo $row->get('id'); ?>" data-text-follow="<?php echo JText::_('Follow'); ?>" data-text-unfollow="<?php echo JText::_('Unfollow'); ?>" href="<?php echo JRoute::_($base . '&task=' . $row->get('alias') . '/follow'); ?>">
+								<span><?php echo JText::_('Follow'); ?></span>
 							</a>
 						<?php } ?>
 					<?php } ?>
@@ -177,7 +199,7 @@ if ($this->rows->total() > 0)
 				<?php if ($row->get('object_type') == 'member' && $row->get('object_id') != $this->juser->get('id')) { ?>
 				<div class="convo attribution clearfix">
 					<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $row->get('created_by')); ?>" title="<?php echo $this->escape(stripslashes($row->creator()->get('name'))); ?>" class="img-link">
-						<img src="<?php echo Hubzero_User_Profile_Helper::getMemberPhoto($row->creator(), 0); ?>" alt="<?php echo JText::sprintf('PLG_MEMBERS_COLLECTIONS_PROFILE_PICTURE', $this->escape(stripslashes($row->creator()->get('name')))); ?>" />
+						<img src="<?php echo Hubzero_User_Profile_Helper::getMemberPhoto($row->creator(), 0); ?>" alt="Profile picture of <?php echo $this->escape(stripslashes($row->creator()->get('name'))); ?>" />
 					</a>
 					<p>
 						<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $row->get('created_by')); ?>">
@@ -186,10 +208,8 @@ if ($this->rows->total() > 0)
 
 						<br />
 						<span class="entry-date">
-							<span class="entry-date-at"><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_AT'); ?></span> 
-							<span class="date"><time datetime="<?php echo $row->get('created'); ?>"><?php echo JHTML::_('date', $row->get('created'), JText::_('TIME_FORMAt_HZ1')); ?></time></span> 
-							<span class="entry-date-on"><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_ON'); ?></span> 
-							<span class="time"><time datetime="<?php echo $row->get('created'); ?>"><?php echo JHTML::_('date', $row->get('created'), JText::_('DATE_FORMAt_HZ1')); ?></time></span>
+							<span class="entry-date-at">@</span> <span class="date"><time datetime="<?php echo $row->get('created'); ?>"><?php echo JHTML::_('date', $row->get('created'), $this->timeFormat, $this->tz); ?></time></span> 
+							<span class="entry-date-on">on</span> <span class="time"><time datetime="<?php echo $row->get('created'); ?>"><?php echo JHTML::_('date', $row->get('created'), $this->dateFormat, $this->tz); ?></time></span>
 						</span>
 					</p>
 				</div><!-- / .attribution -->
@@ -205,18 +225,18 @@ if ($this->rows->total() > 0)
 		<?php if ($this->params->get('access-create-collection')) { ?>
 			<div class="instructions">
 				<ol>
-					<li><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_COLLECTION_INSTRUCTIONS_STEP1'); ?></li>
-					<li><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_COLLECTION_INSTRUCTIONS_STEP2'); ?></li>
-					<li><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_COLLECTION_INSTRUCTIONS_STEP3'); ?></li>
+					<li><?php echo JText::_('Click on the "new collection" button.'); ?></li>
+					<li><?php echo JText::_('Add a title and maybe a description.'); ?></li>
+					<li><?php echo JText::_('Start adding content!'); ?></li>
 				</ol>
 			</div><!-- / .instructions -->
 			<div class="questions">
-				<p><strong><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_WHAT_IS_COLLECTION'); ?></strong></p>
-				<p><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_WHAT_IS_COLLECTION_EXPLANATION'); ?></p>
+				<p><strong><?php echo JText::_('What is a collection?'); ?></strong></p>
+				<p><?php echo JText::_('A collection is where you organize posts by topic. For example, you could collect diagrams, files, resources, or wiki pages about physics for your Physics 101 collection. Collections can be private or public.'); ?></p>
 			</div>
 		<?php } else { ?>
 			<div class="instructions">
-				<p><?php echo JText::_('PLG_MEMBERS_COLLECTIONS_NONE'); ?></p>
+				<p><?php echo JText::_('No collections available.'); ?></p>
 			</div><!-- / .instructions -->
 		<?php } ?>
 		</div><!-- / #collection-introduction -->
