@@ -53,8 +53,7 @@ $next_start = $this->filters['start'] + $this->filters['limit'];
 $urlbit = $this->task == 'edit' ? 'edit=team' : 'step=1';
 
 // Use alias or id in urls?
-$use_alias = $this->config->get('use_alias', 0);
-$goto  = $use_alias ? 'alias='.$this->project->alias : 'id='.$this->project->id;
+$goto  = 'alias='.$this->project->alias;
 
 JPluginHelper::importPlugin( 'hubzero' );
 $dispatcher =& JDispatcher::getInstance();
@@ -134,10 +133,13 @@ $dispatcher =& JDispatcher::getInstance();
 	{
 					$thumb = '';
 					
-					if($owner->picture) {
+					if ($owner->picture) {
 						$curthumb = $ih->createThumbName($owner->picture);
 						$thumb = $path.DS.Hubzero_View_Helper_Html::niceidformat($owner->userid).DS.$curthumb;
 					}
+					if (!$thumb or !is_file(JPATH_ROOT.$thumb)) {
+						$thumb = $path . DS . Hubzero_View_Helper_Html::niceidformat($owner->userid) . DS . 'thumb.png';
+					}
 					if (!$thumb or !is_file(JPATH_ROOT.$thumb)) {
 						$thumb = $mconfig->get('defaultpic');
 						if (substr($thumb, 0, 1) != DS) {
